// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>Abstract super-class for 1-Wire Monitors, a optionally-threadable
 * object for searching 1-Wire networks.  If this object is not run in it's own
 * thread, it is possible to perform single-step searches by calling the search
 * method directly {@see #search(Vector, Vector)}.  The monitor will generate
 * events for device arrivals, device departures, and exceptions from the
 * DSPortAdapter.</P>
 *
 * <P>In a touch-contact environment, it is not suitable to say that a
 * device has "departed" because it was missing for one cycle of searching.
 * In the time it takes to get an iButton into a blue-dot receptor, the
 * monitor could have generated a handful of arrival and departure events.  To
 * circumvent this problem, the device monitor keeps a "missing state count" for
 * each device on the network.  Each search cycle that passes where the device
 * is missing causes it's "missing state count" to be incremented.  Once the
 * device's "missing state count" is equal to the "max state count"
 * {@see #getMaxStateCount()}, a departure event is generated for the device.
 * If the 1-Wire Network is not in a touch environment, it may be unnecessary
 * to use this "missing state count".  In those instances, setting the state
 * count to 1 will disable the feature {@see #setMaxStateCount(int)}.</P>
 *
 * <P>Similarly, the reporting of exceptions could be spurious in a
 * touch-contact environment.  Instead of reporting the exception on each
 * failed search attempt, the monitor will default to retrying the search a
 * handful of times {@see #getMaxErrorCount()} before finally reporting the
 * exception.  To disable this feature, set the max error count to 1
 * {@see #setMaxErrorCount(int)}.</P>
 *
 * <P>To receive events, an object must implement the
 * <code>DeviceMonitorEventListener</code> interface
 * {@see DeviceMonitorEventListener} and must be added to
 * the list of listeners {@see #addDeviceMonitorEventListener}.</P>
 *
 * @author SH
 * @version 1.00
 */
public class AbstractDeviceMonitor

{

   com.dalsemi.onewire.application.monitor.AbstractDeviceMonitor objectInstance  = null;

   /**
    * Default constructor. Does nothing.
    */
   public AbstractDeviceMonitor()
   {
   }

   AbstractDeviceMonitor(com.dalsemi.onewire.application.monitor.AbstractDeviceMonitor o)
   {
      this.objectInstance = o;
   }
   AbstractDeviceMonitor(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.application.monitor.AbstractDeviceMonitor)o);
   }

   /**
    * The device monitor will internally cache OneWireContainer objects for each
    * 1-Wire device.  Use this method to clean up all stale container objects.
    * A stale container object is a OneWireContainer object which references a
    * 1-Wire device address which has not been seen by a recent search.
    * This will be essential in a touch-contact environment which could run
    * for some time and needs to conserve memory.
    */
   public void cleanUpStaleContainerReferences()
   {      
      objectInstance.cleanUpStaleContainerReferences();
   }

   /**
    * The device monitor will internally cache OWPath objects for each
    * 1-Wire device.  Use this method to clean up all stale OWPath objects.
    * A stale path object is a OWPath which references a branching path to a
    * 1-Wire device address which has not been seen by a recent search.
    * This will be essential in a touch-contact environment which could run
    * for some time and needs to conserve memory.
    */
   public void cleanUpStalePathReferences()
   {      
      objectInstance.cleanUpStalePathReferences();
   }

   /**
    * Resets this device monitor.  All known devices will be marked as
    * "departed" and departure events will be fired.
    */
   public void resetSearch()
   {      
      objectInstance.resetSearch();
   }

   /**
    * The number of searches that a button should be "missing"
    * before it is removed.
    *
    * @return The number of searches that a button should be "missing"
    * before it is removed.
    */
   public int getMaxStateCount()
   {      
      return objectInstance.getMaxStateCount();
   }

   /**
    * The number of searches that a button should be "missing"
    * before it is removed
    *
    * @param stateCnt The number of searches that a button should be "missing"
    * before it is removed.
    */
   public void setMaxStateCount(int stateCnt)
   {      
      objectInstance.setMaxStateCount(stateCnt);
   }

   /**
    * Number of searches that an error occurs before listener's are notified
    *
    * @return Number of searches that an error occurs before listener's
    * are notified
    */
   public int getMaxErrorCount()
   {      
      return objectInstance.getMaxErrorCount();
   }

   /**
    * Number of searches that an error occurs before listener's are notified
    *
    * @param errorCnt Number of searches that an error occurs before listener's
    * are notified
    */
   public void setMaxErrorCount(int errorCnt)
   {      
      objectInstance.setMaxErrorCount(errorCnt);
   }

   /**
    * Returns the DSPortAdapter this device is searching
    *
    * @param the DSPortAdapter this monitor is searching
    */
   public DSPortAdapter getAdapter()
   {      
      return new DSPortAdapter(objectInstance.getAdapter());
   }

   /**
    * Sets this monitor to search a new DSPortAdapter
    *
    * @param the DSPortAdapter this monitor should search
    */
   public void setAdapter(DSPortAdapter adapter)
   {      
      objectInstance.setAdapter(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance));
   }

   /**
    * Performs a search of the 1-Wire network
    *
    * @param arrivals A vector of Long objects, represent new arrival addresses.
    * @param departures A vector of Long objects, represent departed addresses.
    */
   public void search(java.util.Vector arrivals, java.util.Vector departures)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance.search(arrivals, departures);
   }

   /**
    * Pause this monitor
    *
    * @param blocking if true, this method will block until the monitor is paused.
    * @returns true if the monitor was successfully paused.
    */
   public boolean pauseMonitor(boolean blocking)
   {      
      return objectInstance.pauseMonitor(blocking);
   }

   /**
    * Resume this monitor
    *
    * @param blocking if true, this method will block until the monitor is resumed.
    * @returns true if the monitor was successfully resumed.
    */
   public boolean resumeMonitor(boolean blocking)
   {      
      return objectInstance.resumeMonitor(blocking);
   }

   /**
    * Check if this monitor is running.
    *
    * @return <CODE>true</CODE> if monitor is running
    */
   public boolean isMonitorRunning()
   {      
      return objectInstance.isMonitorRunning();
   }

   /**
    * Kill this monitor.  Wait util this
    * thread is no longer alive (with timeout).
    */
   public void killMonitor()
   {      
      objectInstance.killMonitor();
   }

   /**
    * Monitor run method that performs a periodic search
    * of the entire 1-Wire network.  Listeners
    * that have registered are notified when changes in the network
    * are detected.
    */
   public void run()
   {      
      objectInstance.run();
   }

   /**
    * Returns the OWPath of the device with the given address.
    *
    * @param address a byte array representing the address of the device
    * @return The OWPath representing the network path to the device.
    */
   public OWPath getDevicePathFromBytes(ByteArray address)
   {      
      return new OWPath(objectInstance.getDevicePath(address.array));
   }

   /**
    * Returns the OWPath of the device with the given address.
    *
    * @param address a string representing the address of the device
    * @return The OWPath representing the network path to the device.
    */
   public OWPath getDevicePathFromString(java.lang.String address)
   {      
      return new OWPath(objectInstance.getDevicePath(address));
   }

   /**
    * Returns the OWPath of the device with the given address.
    *
    * @param address a long representing the address of the device
    * @return The OWPath representing the network path to the device.
    */
   public OWPath getDevicePathFromLong(String address)
   {      
      return new OWPath(objectInstance.getDevicePath(Long.parseLong(address)));
   }

   /**
    * Returns the OWPath of the device with the given address.
    *
    * @param address a Long object representing the address of the device
    * @return The OWPath representing the network path to the device.
    */
   public OWPath getDevicePathFromLongObject(java.lang.Long address)
   {      
      return new OWPath(objectInstance.getDevicePath(address));
   }

   /**
    * Returns all addresses known by this monitor as an Enumeration of Long
    * objects.
    *
    * @return Enumeration of Long objects
    */
   public StringEnumeration getAllAddresses()
   {      
      return new StringEnumeration().setupObject(objectInstance.getAllAddresses());
   }

   /**
    * Returns the OneWireContainer object of the device with the given address.
    *
    * @param adapter The DSPortAdapter that the device is connected to.
    * @param address a byte array representing the address of the device
    * @return The specific OneWireContainer object of the device
    */
   public OneWireContainer getDeviceContainerFromBytes(DSPortAdapter adapter, ByteArray address)
   {      
      return new OneWireContainer(com.dalsemi.onewire.application.monitor.AbstractDeviceMonitor.getDeviceContainer(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), address.array));
   }

   /**
    * Returns the OneWireContainer object of the device with the given address.
    *
    * @param adapter The DSPortAdapter that the device is connected to.
    * @param address a String representing the address of the device
    * @return The specific OneWireContainer object of the device
    */
   public OneWireContainer getDeviceContainerFromString(DSPortAdapter adapter, java.lang.String address)
   {      
      return new OneWireContainer(com.dalsemi.onewire.application.monitor.AbstractDeviceMonitor.getDeviceContainer(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), address));
   }

   /**
    * Returns the OneWireContainer object of the device with the given address.
    *
    * @param adapter The DSPortAdapter that the device is connected to.
    * @param address a long representing the address of the device
    * @return The specific OneWireContainer object of the device
    */
   public OneWireContainer getDeviceContainerFromLong(DSPortAdapter adapter, String address)
   {      
      return new OneWireContainer(com.dalsemi.onewire.application.monitor.AbstractDeviceMonitor.getDeviceContainer(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), Long.parseLong(address)));
   }

   /**
    * Returns the OneWireContainer object of the device with the given address.
    *
    * @param adapter The DSPortAdapter that the device is connected to.
    * @param address a Long object representing the address of the device
    * @return The specific OneWireContainer object of the device
    */
   public OneWireContainer getDeviceContainerFromLongObject(DSPortAdapter adapter, java.lang.Long longAddress)
   {      
      return new OneWireContainer(com.dalsemi.onewire.application.monitor.AbstractDeviceMonitor.getDeviceContainer(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), longAddress));
   }

   /**
    * Sets the OneWireContainer object of the device with the given address.
    *
    * @param address a byte array object representing the address of the device
    * @param owc The specific OneWireContainer object of the device
    */
   public void putDeviceContainerFromBytes(ByteArray address, OneWireContainer owc)
   {      
      com.dalsemi.onewire.application.monitor.AbstractDeviceMonitor.putDeviceContainer(address.array, ((com.dalsemi.onewire.container.OneWireContainer)owc.objectInstance));
   }

   /**
    * Sets the OneWireContainer object of the device with the given address.
    *
    * @param address a String object representing the address of the device
    * @param owc The specific OneWireContainer object of the device
    */
   public void putDeviceContainerFromString(java.lang.String address, OneWireContainer owc)
   {      
      com.dalsemi.onewire.application.monitor.AbstractDeviceMonitor.putDeviceContainer(address, ((com.dalsemi.onewire.container.OneWireContainer)owc.objectInstance));
   }

   /**
    * Sets the OneWireContainer object of the device with the given address.
    *
    * @param address a long object representing the address of the device
    * @param owc The specific OneWireContainer object of the device
    */
   public void putDeviceContainerFromLong(String address, OneWireContainer owc)
   {      
      com.dalsemi.onewire.application.monitor.AbstractDeviceMonitor.putDeviceContainer(Long.parseLong(address), ((com.dalsemi.onewire.container.OneWireContainer)owc.objectInstance));
   }

   /**
    * Sets the OneWireContainer object of the device with the given address.
    *
    * @param address a Long object representing the address of the device
    * @param owc The specific OneWireContainer object of the device
    */
   public void putDeviceContainerFromLongObject(java.lang.Long longAddress, OneWireContainer owc)
   {      
      com.dalsemi.onewire.application.monitor.AbstractDeviceMonitor.putDeviceContainer(longAddress, ((com.dalsemi.onewire.container.OneWireContainer)owc.objectInstance));
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   AbstractDeviceMonitor setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.application.monitor.AbstractDeviceMonitor)o;
      return this;
   }
}
