// COM proxy class, output from FunctionList.js
package owapi;
/**
 * Utilities to translate and verify the 1-Wire Network address.
 * <p>
 * Q: What is a 1-Wire Network Address?<p>
 * A: A 1-Wire address is 64 bits consisting of an eight bit family code, forty eight
 * bits of serialized data and an eight bit CRC8 of the first 56 bits.
 * <p>
 * For example given the following address in hexadecimal:
 * <p>
 * 10 28 E9 14 00 00 00 F3
 * <p>
 * The above is a family code 10 device with a serialized data
 * of 28 E9 14 00 00 00, and a CRC8 of F3.
 * <p>
 * The address can be stored in several ways:
 * <ul>
 * <li>
 * As a little-endian byte array:<p>
 * <code>byte[] address = { 0x10, (byte)0xE9, 0x14, 0x00, 0x00, 0x00, (byte)0xF3 };</code><p>
 * </li>
 * <li>
 * As a big-endian long:<p>
 * <code>long address = (long)0xF300000014E92810;</code><p>
 * </li>
 * <li>
 * As a big-endian String:<p>
 * <code>String address = "F300000014E92810";</code><p>
 * </li>
 * </ul>
 * @version CLSID=0F063EEC-0277-45CB-A2A6-67EE547B65C3 -     0.00, 21 August 2000
 * @author     DS
 * @com.register ( clsid=0F063EEC-0277-45CB-A2A6-67EE547B65C3, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class Address
   implements com.ms.com.IUnknown
{


   /**
    * Checks the CRC8 calculation of this 1-Wire Network address.
    * <p>
    * The address is valid if the CRC8 of the first seven bytes of the address gives
    * a result equal to the eighth byte.
    *
    * @param  address  iButton or 1-Wire Network address to verify
    *
    * @return <code>true</code> if the family code is non-zero and the
    * CRC8 calculation is correct.
    * @see        CRC8
    */
   public boolean isValidFromBytes(ByteArray a0)
   {      
      return com.dalsemi.onewire.utils.Address.isValid(a0.array);
   }

   /**
    * Checks the CRC8 calculation of this 1-Wire Network address.
    * <p>
    * The address is valid if the CRC8 of the first seven bytes of the address gives
    * a result equal to the eighth byte.
    *
    * @param  address  iButton or 1-Wire Network address to verify
    *
    * @return <code>true</code> if the family code is non-zero and the
    * CRC8 calculation is correct.
    * @see        CRC8
    */
   public boolean isValid(java.lang.String a0)
   {      
      return com.dalsemi.onewire.utils.Address.isValid(a0);
   }

   /**
    * Checks the CRC8 calculation of this 1-Wire Network address.
    * <p>
    * The address is valid if the CRC8 of the first seven bytes of the address gives
    * a result equal to the eighth byte.
    *
    * @param  address  iButton or 1-Wire Network address to verify
    *
    * @return <code>true</code> if the family code is non-zero and the
    * CRC8 calculation is correct.
    * @see        CRC8
    */
   public boolean isValidFromLong(String a0)
   {      
      return com.dalsemi.onewire.utils.Address.isValid(Long.parseLong(a0));
   }

   /**
    * Converts a 1-Wire Network address byte array (little endian)
    * to a hex string representation (big endian).
    *
    * @param address family code first.
    *
    * @return address represented in a String, family code last.
    */
   public java.lang.String toStringFromBytes(ByteArray address)
   {      
      return com.dalsemi.onewire.utils.Address.toString(address.array);
   }

   /**
    * Converts a 1-Wire Network address long (little endian)
    * to a hex string representation (big endian).
    *
    * @param address family code first.
    *
    * @return address represented in a long, little endian.
    */
   public java.lang.String toStringFromLong(String address)
   {      
      return com.dalsemi.onewire.utils.Address.toString(Long.parseLong(address));
   }

   /**
    * Converts a 1-Wire Network Address string (big endian)
    * to a byte array (little endian).
    *
    * @param address family code last.
    *
    * @return address represented in a byte array, family
    *                 code (LS byte) first.
    */
   public ByteArray toByteArray(java.lang.String address)
   {      
      return new ByteArray().setupObject(com.dalsemi.onewire.utils.Address.toByteArray(address));
   }

   /**
    * Convert an iButton or 1-Wire device address as a long
    * (little endian) into an array of bytes.
    */
   public ByteArray toByteArrayFromLong(String address)
   {      
      return new ByteArray().setupObject(com.dalsemi.onewire.utils.Address.toByteArray(Long.parseLong(address)));
   }

   /**
    * Converts a 1-Wire Network Address to a long (little endian).
    *
    * @return address represented as a long.
    */
   public String toLongFromBytes(ByteArray address)
   {      
      return ""+com.dalsemi.onewire.utils.Address.toLong(address.array);
   }

   /**
    * Converts a 1-Wire Network Address to a long (little endian).
    *
    * @return address represented as a String.
    */
   public String toLong(java.lang.String address)
   {      
      return ""+com.dalsemi.onewire.utils.Address.toLong(address);
   }


}
