// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> One-Time-Programmable (OTP) Memory bank interface for iButtons (or 1-Wire devices) 
 * with OTP features.  This interface extents the base functionality of
 * the super-interfaces {@link MemoryBank MemoryBank}
 * and {@link PagedMemoryBank PagedMemoryBank}
 * by providing One-Time-Programmable services. </P> 
 *
 * <P>The OTPMemoryBank methods can be organized into the following categories: </P>
 * <UL>
 *   <LI> <B> Information </B>
 *     <UL>
 *       <LI> {@link #canRedirectPage() canRedirectPage} 
 *       <LI> {@link #canLockPage() canLockPage} 
 *       <LI> {@link #canLockRedirectPage() canLockRedirectPage} 
 *     </UL>
 *   <LI> <B> Read Status </B>
 *     <UL>
 *       <LI> {@link #getRedirectedPage(int) getRedirectedPage} 
 *       <LI> {@link #isPageLocked(int) isPageLocked} 
 *       <LI> {@link #isRedirectPageLocked(int) isRedirectPageLocked} 
 *     </UL>
 *   <LI> <B> Write Status </B>
 *     <UL>
 *       <LI> {@link #redirectPage(int,int) redirectPage} 
 *       <LI> {@link #lockPage(int) lockPage} 
 *       <LI> {@link #lockRedirectPage(int) lockRedirectPage} 
 *     </UL>
 *  </UL>
 *
 * <H3> Usage </H3> 
 *  
 * <DL> 
 * <DD> <H4> Example 1</H4> 
 * Read the OTP status of page 0 in the OTPMemoryBank instance 'otp':
 * <PRE> <CODE>
 *  if (otp.canRedirectPage())
 *  {
 *     int new_page = getRedirectedPage(0);
 *     if (new_page != 0)
 *        System.out.println("Page 0 is redirected to " + new_page);
 *  }
 * 
 *  if (otp.canLockPage())
 *  {
 *     if (otp.isPageLocked(0))
 *        System.out.println("Page 0 is locked");
 *  }
 *
 *  if (otp.canLockRedirectPage())
 *  {
 *     if (otp.isRedirectPageLocked(0))
 *        System.out.println("Page 0 redirection is locked");
 *  }
 * </CODE> </PRE>
 *
 * <DD> <H4> Example 1</H4> 
 * Lock all of the pages in the OTPMemoryBank instance 'otp':
 * <PRE> <CODE>
 *  if (otp.canLockPage())
 *  {
 *     // loop to lock each page  
 *     for (int pg = 0; pg < otp.getNumberPages(); pg++)
 *     {
 *        otp.lockPage(pg);
 *     }
 *  }
 *  else
 *     System.out.println("OTPMemoryBank does not support page locking");
 * </CODE> </PRE>
 * </DL>
 *
 * @see MemoryBank
 * @see PagedMemoryBank
 * @see OneWireContainer09
 * @see OneWireContainer0B
 * @see OneWireContainer0F
 * @see OneWireContainer12
 * @see OneWireContainer13
 *
 * @version CLSID=2417E93A-3606-4426-A5DE-D09AC41CF97F -     0.01, 11 Dec 2000
 * @author     DS
 * @com.register ( clsid=2417E93A-3606-4426-A5DE-D09AC41CF97F, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OTPMemoryBank
   extends PagedMemoryBank
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: PagedMemoryBank
   //com.dalsemi.onewire.container.OTPMemoryBank objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use buildFromObject method to initialize.
    */
   public OTPMemoryBank()
   {
   }

   OTPMemoryBank(com.dalsemi.onewire.container.OTPMemoryBank o)
   {
      super(o);
   }
   OTPMemoryBank(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OTPMemoryBank)o);
   }

   /**
    * Checks to see if this memory bank has pages that can be redirected
    * to a new page.  This is used in Write-Once memory
    * to provide a means to update.
    *
    * @return  <CODE> true </CODE> if this memory bank pages can be redirected
    *          to a new page
    *
    * @see #redirectPage(int,int) redirectPage
    * @see #getRedirectedPage(int) getRedirectedPage
    */
   public boolean canRedirectPage()
   {      
      return ((com.dalsemi.onewire.container.OTPMemoryBank)objectInstance).canRedirectPage();
   }

   /**
    * Checks to see if this memory bank has pages that can be locked.  A
    * locked page would prevent any changes to it's contents.
    *
    * @return  <CODE> true </CODE> if this memory bank has pages that can be 
    *          locked
    *
    * @see #lockPage(int) lockPage
    * @see #isPageLocked(int) isPageLocked
    */
   public boolean canLockPage()
   {      
      return ((com.dalsemi.onewire.container.OTPMemoryBank)objectInstance).canLockPage();
   }

   /**
    * Checks to see if this memory bank has pages that can be locked from
    * being redirected.  This would prevent a Write-Once memory from
    * being updated.
    *
    * @return  <CODE> true </CODE> if this memory bank has pages that can 
    *          be locked from being redirected to a new page

    * @see #lockRedirectPage(int) lockRedirectPage
    * @see #isRedirectPageLocked(int) isRedirectPageLocked
    */
   public boolean canLockRedirectPage()
   {      
      return ((com.dalsemi.onewire.container.OTPMemoryBank)objectInstance).canLockRedirectPage();
   }

   /**
    * Locks the specifed page in this memory bank.  Not supported
    * by all devices. 
    *
    * @param  page   number of page to lock
    *
    * @throws OneWireIOException on a 1-Wire communication error such as 
    *         no device present or a read back verification fails.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to 
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire 
    *         adapter.  It will also be thrown if the device needs 'program' voltage
    *         and the adapter used by this device does not support it.
    *
    * @see #isPageLocked(int) isPageLocked
    * @see #canLockPage() canLockPage
    * @see canProgram()
    */
   public void lockPage(int a0)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OTPMemoryBank)objectInstance).lockPage(a0);
   }

   /**
    * Checks to see if the specified page is locked.
    *
    * @param  page  page to check 
    *
    * @return  <CODE> true </CODE> if page is locked
    *
    * @throws OneWireIOException on a 1-Wire communication error such as 
    *         no device present or a CRC read from the device is incorrect.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to 
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire 
    *         adapter.  
    *
    * @see #lockPage(int) lockPage
    * @see #canLockPage() canLockPage
    */
   public boolean isPageLocked(int page)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OTPMemoryBank)objectInstance).isPageLocked(page);
   }

   /**
    * Redirects the specifed page to a new page.
    * Not supported by all devices. 
    *
    * @param  page      number of page to redirect
    * @param  newPage   new page number to redirect to
    *
    * @throws OneWireIOException on a 1-Wire communication error such as 
    *         no device present or a CRC read from the device is incorrect.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to 
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire 
    *         adapter.  It will also be thrown if the device needs 'program' voltage
    *         and the adapter used by this device does not support it.
    *
    * @see #canRedirectPage() canRedirectPage
    * @see #getRedirectedPage(int) getRedirectedPage
    * @see canProgram()
    */
   public void redirectPage(int a0, int a1)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OTPMemoryBank)objectInstance).redirectPage(a0, a1);
   }

   /**
    * Checks to see if the specified page is redirected.
    * Not supported by all devices. 
    *
    * @param  page  page to check for redirection
    *
    * @return  the new page number or 0 if not redirected
    *
    * @throws OneWireIOException on a 1-Wire communication error such as 
    *         no device present or a CRC read from the device is incorrect.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to 
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire 
    *         adapter.  
    *
    * @see #canRedirectPage() canRedirectPage
    * @see #redirectPage(int,int) redirectPage
    *
    * @deprecated  As of 1-Wire API 0.01, replaced by {@link #getRedirectedPage(int)}
    */
   public int isPageRedirected(int page)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OTPMemoryBank)objectInstance).isPageRedirected(page);
   }

   /**
    * Gets the page redirection of the specified page.
    * Not supported by all devices. 
    *
    * @param  page  page to check for redirection
    *
    * @return  the new page number or 0 if not redirected
    *
    * @throws OneWireIOException on a 1-Wire communication error such as 
    *         no device present or a CRC read from the device is incorrect.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to 
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire 
    *         adapter.  
    *
    * @see #canRedirectPage() canRedirectPage
    * @see #redirectPage(int,int) redirectPage
    * @since 1-Wire API 0.01
    */
   public int getRedirectedPage(int page)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OTPMemoryBank)objectInstance).getRedirectedPage(page);
   }

   /**
    * Locks the redirection of the specifed page. 
    * Not supported by all devices.  
    *
    * @param  page  page to redirect
    *
    * @throws OneWireIOException on a 1-Wire communication error such as 
    *         no device present or a CRC read from the device is incorrect.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to 
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire 
    *         adapter.  It will also be thrown if the device needs 'program' voltage
    *         and the adapter used by this device does not support it.
    *
    * @see #canLockRedirectPage() canLockRedirectPage
    * @see #isRedirectPageLocked(int) isRedirectPageLocked
    * @see canProgram()
    */
   public void lockRedirectPage(int a0)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OTPMemoryBank)objectInstance).lockRedirectPage(a0);
   }

   /**
    * Checks to see if the specified page has redirection locked.
    * Not supported by all devices.  
    *
    * @param  page  page to check for locked redirection
    *
    * @return  <CODE> true </CODE> if redirection is locked for this page
    *
    * @throws OneWireIOException on a 1-Wire communication error such as 
    *         no device present or a CRC read from the device is incorrect.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to 
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire 
    *         adapter.  
    *
    * @see #canLockRedirectPage() canLockRedirectPage
    * @see #lockRedirectPage(int) lockRedirectPage
    */
   public boolean isRedirectPageLocked(int page)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OTPMemoryBank)objectInstance).isRedirectPageLocked(page);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   MemoryBank setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OTPMemoryBank)o;
      return this;
   }
}
