// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire container for 512 byte memory iButton Plus Time, DS1994 and 1-Wire Chip, DS2404.
 * This container encapsulates the functionality of the iButton family
 * type <B>04</B> (hex)</P>
 *
 * <P> This iButton is primarily used as a read/write portable memory device with real-time-clock,
 *  timer and experation features. </P>
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> 4096 bits (512 bytes) of read/write nonvolatile memory
 *   <LI> 256-bit (32-byte) scratchpad ensures integrity of data
 *        transfer
 *   <LI> Memory partitioned into 256-bit (32-byte) pages for
 *        packetizing data
 *   <LI> Data integrity assured with strict read/write
 *        protocols
 *   <LI> Contains real time clock/calendar in binary
 *        format
 *   <LI> Interval timer can automatically accumulate
 *        time when power is applied
 *   <LI> Programmable cycle counter can accumulate
 *        the number of system power-on/off cycles
 *   <LI> Programmable alarms can be set to generate
 *        interrupts for interval timer, real time clock,
 *        and/or cycle counter
 *   <LI> Write protect feature provides tamper-proof
 *        time data
 *   <LI> Programmable expiration date that will limit
 *        access to SRAM and timekeeping
 *   <LI> Clock accuracy is better than 2 minute/
 *        month at 25&#176C
 *   <LI> Operating temperature range from -40&#176C to
 *        +70&#176C
 *   <LI> Over 10 years of data retention
 * </UL>
 *
 * <P> Appended to the clock page data retrieved with 'readDevice'
 * are 4 bytes that represent a bitmap
 * of changed bytes.  These bytes are used in the 'writeDevice' method
 * in conjuction with the 'set' methods to only write back the changed
 * clock register bytes.  The 'readDevice' method will clear any
 * pending alarms. </P>
 *
 * <P> WARNING: If write-protect alarm options have been set prior
 * to a call to 'writeDevice' then the operation is non-reversable. </P>
 *
 * <H3> Alternate Names </H3>
 * <UL>
 *   <LI> D2504
 *   <LI> D1427 (family type 84 hex)
 * </UL>
 *
 * <H3> Memory </H3>
 *
 * <P> The memory can be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 *
 * The following is a list of the MemoryBank instances that are returned:
 *
 * <UL>
 *   <LI> <B> Scratchpad </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                   {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write not-general-purpose volatile
 *         <LI> <I> Pages</I> 1 pages of length 32 bytes
 *         <LI> <I> Extra information for each page</I>  Target address, offset, length 3
 *      </UL>
 *   <LI> <B> Main Memory </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 512 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 16 pages of length 32 bytes giving 29 bytes Packet data payload
 *      </UL>
 *   <LI> <B> Clock/alarm registers </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32 starting at physical address 512
 *         <LI> <I> Features</I> Read/Write not-general-purpose non-volatile
 *         <LI> <I> Pages</I> 1 pages of length 32 bytes
 *      </UL>
 * </UL>
 *
 * <H3> Clock </H3>
 *
 * <P>The clock methods can be organized into the following categories.  Note that methods
 *    that are implemented for the {@link ClockContainer ClockContainer}
 *    interface are marked with (*): </P>
 * <UL>
 *   <LI> <B> Information </B>
 *     <UL>
 *       <LI> {@link #hasClockAlarm() hasClockAlarm} *
 *       <LI> {@link #canDisableClock() canDisableClock} *
 *       <LI> {@link #getClockResolution() getClockResolution} *
 *     </UL>
 *   <LI> <B> Read </B>
 *     <UL>
 *       <LI> <I> Clock </I>
 *         <UL>
 *           <LI> {@link #getClock(byte[]) getClock} *
 *           <LI> {@link #getClockAlarm(byte[]) getClockAlarm} *
 *           <LI> {@link #isClockAlarming(byte[]) isClockAlarming} *
 *           <LI> {@link #isClockAlarmEnabled(byte[]) isClockAlarmEnabled} *
 *           <LI> {@link #isClockRunning(byte[]) isClockRunning} *
 *           <LI> {@link #isClockWriteProtected(byte[]) isClockWriteProtected}
 *         </UL>
 *       <LI> <I> Interval Timer </I>
 *         <UL>
 *           <LI> {@link #getIntervalTimer(byte[]) getIntervalTimer}
 *           <LI> {@link #getIntervalTimerAlarm(byte[]) getIntervalTimerAlarm}
 *           <LI> {@link #isIntervalTimerAlarming(byte[]) isIntervalTimerAlarming}
 *           <LI> {@link #isIntervalTimerAlarmEnabled(byte[]) isIntervalTimerAlarmEnabled}
 *           <LI> {@link #isIntervalTimerWriteProtected(byte[]) isIntervalTimerWriteProtected}
 *           <LI> {@link #isIntervalTimerAutomatic(byte[]) isIntervalTimerAutomatic}
 *           <LI> {@link #isIntervalTimerStopped(byte[]) isIntervalTimerStopped}
 *         </UL>
 *       <LI> <I> Power Cycle Counter </I>
 *         <UL>
 *           <LI> {@link #getCycleCounter(byte[]) getCycleCounter}
 *           <LI> {@link #getCycleCounterAlarm(byte[]) getCycleCounterAlarm}
 *           <LI> {@link #isCycleCounterAlarming(byte[]) isCycleCounterAlarming}
 *           <LI> {@link #isCycleCounterAlarmEnabled(byte[]) isCycleCounterAlarmEnabled}
 *           <LI> {@link #isCycleCounterWriteProtected(byte[]) isCycleCounterWriteProtected}
 *         </UL>
 *       <LI> <I> Misc </I>
 *         <UL>
 *           <LI> {@link #readDevice() readDevice} *
 *           <LI> {@link #isAutomaticDelayLong(byte[]) isAutomaticDelayLong}
 *           <LI> {@link #canReadAfterExpire(byte[]) canReadAfterExpire}
 *         </UL>
 *     </UL>
 *   <LI> <B> Write </B>
 *     <UL>
 *       <LI> <I> Clock </I>
 *         <UL>
 *           <LI> {@link #setClock(long, byte[]) setClock} *
 *           <LI> {@link #setClockAlarm(long, byte[]) setClockAlarm} *
 *           <LI> {@link #setClockRunEnable(boolean, byte[]) setClockRunEnable} *
 *           <LI> {@link #setClockAlarmEnable(boolean, byte[]) setClockAlarmEnable} *
 *           <LI> {@link #writeProtectClock(byte[]) writeProtectClock}
 *         </UL>
 *       <LI> <I> Interval Timer </I>
 *         <UL>
 *           <LI> {@link #setIntervalTimer(long, byte[]) setIntervalTimer}
 *           <LI> {@link #setIntervalTimerAlarm(long, byte[]) setIntervalTimerAlarm}
 *           <LI> {@link #writeProtectIntervalTimer(byte[]) writeProtectIntervalTimer}
 *           <LI> {@link #setIntervalTimerAutomatic(boolean, byte[]) setIntervalTimerAutomatic}
 *           <LI> {@link #setIntervalTimerRunState(boolean, byte[]) setIntervalTimerRunState}
 *           <LI> {@link #setIntervalTimerAlarmEnable(boolean, byte[]) setIntervalTimerAlarmEnable}
 *         </UL>
 *       <LI> <I> Power Cycle Counter </I>
 *         <UL>
 *           <LI> {@link #setCycleCounter(long, byte[]) setCycleCounter}
 *           <LI> {@link #setCycleCounterAlarm(long, byte[]) setCycleCounterAlarm}
 *           <LI> {@link #writeProtectCycleCounter(byte[]) writeProtectCycleCounter}
 *           <LI> {@link #setCycleCounterAlarmEnable(boolean, byte[]) setCycleCounterAlarmEnable}
 *         </UL>
 *       <LI> <I> Misc </I>
 *         <UL>
 *           <LI> {@link #writeDevice(byte[]) writeDevice} *
 *           <LI> {@link #setReadAfterExpire(boolean, byte[]) setReadAfterExpire}
 *           <LI> {@link #setAutomaticDelayLong(boolean, byte[]) setAutomaticDelayLong}
 *         </UL>
 *     </UL>
 *  </UL>
 *
 * <H3> Usage </H3>
 *
 * <DL>
 * <DD> See the usage examples in
 * {@link ClockContainer ClockContainer}
 * for basic clock operations.
 * <DD> See the usage example in
 * {@link OneWireContainer OneWireContainer}
 * to enumerate the MemoryBanks.
 * <DD> See the usage examples in
 * {@link MemoryBank MemoryBank} and
 * {@link PagedMemoryBank PagedMemoryBank}
 * for bank specific operations.
 * </DL>
 *
 * <H3> DataSheets </H3>
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS1992-DS1994.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS1992-DS1994.pdf</A>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2404.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2404.pdf</A>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS1427.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS1427.pdf</A>
 * </DL>
 *
 * @see MemoryBank
 * @see PagedMemoryBank
 * @see ClockContainer
 *
 * @version CLSID=4E277770-6106-4767-B5F1-16D18D9A8325 -     0.00, 28 Aug 2000
 * @author     DS
 * @com.register ( clsid=4E277770-6106-4767-B5F1-16D18D9A8325, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer04
   extends OneWireContainer
   implements com.ms.com.IUnknown, ClockContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer04 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer04()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer04());
   }

   OneWireContainer04(com.dalsemi.onewire.container.OneWireContainer04 o)
   {
      super(o);
   }
   OneWireContainer04(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer04)o);
   }

   /**
    * Query to see if the clock has an alarm feature.
    *
    * @return true if the Real-Time clock has an alarm
    *
    * @see #getClockAlarm(byte[])
    * @see #isClockAlarmEnabled(byte[])
    * @see #isClockAlarming(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public boolean hasClockAlarm()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).hasClockAlarm();
   }

   /**
    * Query to see if the clock can be disabled.
    *
    * @return true if the clock can be enabled and disabled
    *
    * @see #isClockRunning(byte[])
    * @see #setClockRunEnable(boolean,byte[])
    */
   public boolean canDisableClock()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).canDisableClock();
   }

   /**
    * Query to get the clock resolution in milliseconds
    *
    * @return the clock resolution in milliseconds
    */
   public String getClockResolution()
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).getClockResolution();
   }

   /**
    * Retrieves the 1-Wire device sensor state.  This state is
    * returned as a byte array.  Pass this byte array to the 'get'
    * and 'set' methods.  If the device state needs to be changed then call
    * the 'writeDevice' to finalize the changes.
    *
    * @return 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).readDevice());
   }

   /**
    * Writes the 1-Wire device sensor state that
    * have been changed by 'set' methods.  Only the state registers that
    * changed are updated.  This is done by referencing a field information
    * appended to the state data.
    *
    * @param  state 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).writeDevice(state.array);
   }

   /**
    * Extracts the Real-Time clock value in milliseconds.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the time represented in this clock in milliseconds since 1970
    *
    * @see OneWireSensor#readDevice()
    * @see #setClock(long,byte[])
    */
   public String getClock(ByteArray a0)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).getClock(a0.array);
   }

   /**
    * Extracts the clock alarm value for the Real-Time clock.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return milliseconds since 1970 that the clock alarm is set to
    *
    * @throws OneWireException if this device does not have clock alarms
    *
    * @see OneWireSensor#readDevice()
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #isClockAlarming(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public String getClockAlarm(ByteArray a0)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).getClockAlarm(a0.array);
   }

   /**
    * Checks if the clock alarm flag has been set.
    * This will occur when the value of the Real-Time
    * clock equals the value of the clock alarm.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if the Real-Time clock is alarming
    *
    * @see OneWireSensor#readDevice()
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #getClockAlarm(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public boolean isClockAlarming(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isClockAlarming(a0.array);
   }

   /**
    * Checks if the clock alarm is enabled.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if clock alarm is enabled
    *
    * @see OneWireSensor#readDevice()
    * @see #hasClockAlarm()
    * @see #isClockAlarming(byte[])
    * @see #getClockAlarm(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public boolean isClockAlarmEnabled(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isClockAlarmEnabled(a0.array);
   }

   /**
    * Checks if the device's oscillator is enabled.  The clock
    * will not increment if the clock oscillator is not enabled.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if the clock is running
    *
    * @see OneWireSensor#readDevice()
    * @see #canDisableClock()
    * @see #setClockRunEnable(boolean,byte[])
    */
   public boolean isClockRunning(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isClockRunning(a0.array);
   }

   /**
    * Get the Interval Timer Value in milliseconds.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return time in milliseconds
    * that have occured since the interval counter was started
    *
    * @see OneWireSensor#readDevice()
    * @see #setIntervalTimer(long,byte[])
    */
   public String getIntervalTimer(ByteArray a0)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).getIntervalTimer(a0.array);
   }

   /**
    * Get the power cycle count value.  This is the total number of
    * power cycles that the DS1994 has seen since the counter was reset.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return power cycle count
    *
    * @see OneWireSensor#readDevice()
    * @see #setCycleCounter(long,byte[]) setCycleCounter
    */
   public String getCycleCounter(ByteArray a0)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).getCycleCounter(a0.array);
   }

   /**
    * Get the Interval Timer Alarm Value.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return time in milliseconds that have
    * the interval timer alarm is set to
    *
    * @see OneWireSensor#readDevice()
    * @see #setIntervalTimerAlarm(long,byte[]) setIntervalTimerAlarm
    */
   public String getIntervalTimerAlarm(ByteArray a0)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).getIntervalTimerAlarm(a0.array);
   }

   /**
    * Get the cycle count Alarm Value.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return total number of power cycles
    * that the DS1994 has to to see before the alarm will be triggered
    *
    * @see OneWireSensor#readDevice()
    * @see #setCycleCounterAlarm(long,byte[]) setCycleCounterAlarm
    */
   public String getCycleCounterAlarm(ByteArray a0)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).getCycleCounterAlarm(a0.array);
   }

   /**
    * Check if the Interval Timer Alarm flag has been set.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <CODE>true</CODE> if interval timer is alarming
    *
    * @see OneWireSensor#readDevice()
    * @see #isIntervalTimerAlarmEnabled(byte[]) isIntervalTimerAlarmEnabled
    * @see #setIntervalTimerAlarmEnable(boolean,byte[]) setIntervalTimerAlarmEnable
    */
   public boolean isIntervalTimerAlarming(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isIntervalTimerAlarming(a0.array);
   }

   /**
    * Check if the Cycle Alarm flag has been set.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if cycle counter is alarming
    *
    * @see OneWireSensor#readDevice()
    * @see #isCycleCounterAlarmEnabled(byte[]) isCycleCounterAlarmEnabled
    * @see #setCycleCounterAlarmEnable(boolean,byte[]) setCycleCounterAlarmEnable
    */
   public boolean isCycleCounterAlarming(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isCycleCounterAlarming(a0.array);
   }

   /**
    * Check if the Interval Timer Alarm is enabled.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if interval timer alarm is enabled
    *
    * @see OneWireSensor#readDevice()
    * @see #isIntervalTimerAlarming(byte[]) isIntervalTimerAlarming
    * @see #setIntervalTimerAlarmEnable(boolean,byte[]) setIntervalTimerAlarmEnable
    */
   public boolean isIntervalTimerAlarmEnabled(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isIntervalTimerAlarmEnabled(a0.array);
   }

   /**
    * Check if the Cycle Alarm is enabled.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> true if cycle counter alarm is enabled
    *
    * @see OneWireSensor#readDevice()
    * @see #isCycleCounterAlarming(byte[]) isCycleCounterAlarming
    * @see #setCycleCounterAlarmEnable(boolean,byte[]) setCycleCounterAlarmEnable
    */
   public boolean isCycleCounterAlarmEnabled(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isCycleCounterAlarmEnabled(a0.array);
   }

   /**
    * Check if the Real-Time clock/Alarm is write protected.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if real time clock/alarm is write
    * protected
    *
    * @see OneWireSensor#readDevice()
    * @see #writeProtectClock(byte[]) writeProtectClock
    */
   public boolean isClockWriteProtected(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isClockWriteProtected(a0.array);
   }

   /**
    * Check if the Interval Timer and Interval Timer Alarm
    * register is write protected.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if interval timer and interval timer alarm is
    * write protected
    *
    * @see OneWireSensor#readDevice()
    * @see #writeProtectIntervalTimer(byte[]) writeProtectIntervalTimer
    */
   public boolean isIntervalTimerWriteProtected(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isIntervalTimerWriteProtected(a0.array);
   }

   /**
    * Check if the Cycle Counter and Alarm is write protected.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if cycle counter/alarm is write
    * protected
    *
    * @see OneWireSensor#readDevice()
    * @see #writeProtectCycleCounter(byte[]) writeProtectCycleCounter
    */
   public boolean isCycleCounterWriteProtected(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isCycleCounterWriteProtected(a0.array);
   }

   /**
    * Check if the device can be read after a write protected
    * alarm has occured.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if the device can be read after a
    * write protected alarm has occured
    *
    * @see OneWireSensor#readDevice()
    * @see #setReadAfterExpire(boolean, byte[]) setReadAfterExpire
    */
   public boolean canReadAfterExpire(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).canReadAfterExpire(a0.array);
   }

   /**
    * Checks if the Interval timer is automatic or manual.  If it is
    * automatic then the interval counter will increment while the devices I/O line
    * is high after the delay select period has elapsed (either 3.5 or 123 ms, see
    * the isAutomaticDelayLong() method).
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if the interval timer is set to automatic
    * mode
    *
    * @see OneWireSensor#readDevice()
    * @see #setIntervalTimerAutomatic(boolean, byte[]) setIntervalTimerAutomatic
    */
   public boolean isIntervalTimerAutomatic(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isIntervalTimerAutomatic(a0.array);
   }

   /**
    * Check if the Interval timer is stopped.  This only has meaning
    * if the interval timer is in manual mode (not <CODE>isIntervalTimerAutomatic</CODE>).
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if the interval timer is stopped
    *
    * @see OneWireSensor#readDevice()
    * @see #isIntervalTimerAutomatic(byte[]) isIntervalTimerAutomatic
    * @see #setIntervalTimerAutomatic(boolean, byte[]) setIntervalTimerAutomatic
    * @see #setIntervalTimerRunState(boolean, byte[]) setIntervalTimerRunState
    */
   public boolean isIntervalTimerStopped(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isIntervalTimerStopped(a0.array);
   }

   /**
    * Checks if the automatic delay for the Inteval Timer and the Cycle
    * counter is either 3.5ms (regular) or 123ms (long).
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if the automatic interval/cycle counter
    * delay is in the long (123ms) mode, else it is 3.5ms
    *
    * @see OneWireSensor#readDevice()
    * @see #setAutomaticDelayLong(boolean,byte[]) setAutomaticDelayLong
    */
   public boolean isAutomaticDelayLong(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).isAutomaticDelayLong(a0.array);
   }

   /**
    * Sets the Real-Time clock.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param time new value for the Real-Time clock, in milliseconds
    * since January 1, 1970
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #getClock(byte[])
    */
   public void setClock(String a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setClock(Long.parseLong(a0), a1.array);
   }

   /**
    * Sets the clock alarm.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.  Also note that
    * not all clock devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasClockAlarm()</code> method.
    *
    * @param time - new value for the Real-Time clock alarm, in milliseconds
    * since January 1, 1970
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireException if this device does not have clock alarms
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #getClockAlarm(byte[])
    * @see #isClockAlarming(byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public void setClockAlarm(String a0, ByteArray a1)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setClockAlarm(Long.parseLong(a0), a1.array);
   }

   /**
    * Enables or disables the oscillator, turning the clock 'on' and 'off'.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.  Also note that
    * not all clock devices can disable their oscillators.  Check to see if this device can
    * disable its oscillator first by calling the <code>canDisableClock()</code> method.
    *
    * @param runEnable true to enable the clock oscillator
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireException if the clock oscillator cannot be disabled
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #canDisableClock()
    * @see #isClockRunning(byte[])
    */
   public void setClockRunEnable(boolean a0, ByteArray a1)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setClockRunEnable(a0, a1.array);
   }

   /**
    * Enables or disables the clock alarm.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.  Also note that
    * not all clock devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasClockAlarm()</code> method.
    *
    * @param alarmEnable true to enable the clock alarm
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireException if this device does not have clock alarms
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #getClockAlarm(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #isClockAlarming(byte[])
    */
   public void setClockAlarmEnable(boolean a0, ByteArray a1)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setClockAlarmEnable(a0, a1.array);
   }

   /**
    * Sets the Interval Timer.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param time interval in milliseconds to set (truncated to 1/256th of second)
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #getIntervalTimer(byte[]) getIntervalTimer
    */
   public void setIntervalTimer(String a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setIntervalTimer(Long.parseLong(a0), a1.array);
   }

   /**
    * Sets power Cycle Counter.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param cycles initialize cycle counter value
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #getCycleCounter(byte[]) getCycleCounter
    */
   public void setCycleCounter(String a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setCycleCounter(Long.parseLong(a0), a1.array);
   }

   /**
    * Sets the Interval Timer Alarm.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param time in milliseconds to set the inverval timer
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #getIntervalTimerAlarm(byte[]) getIntervalTimerAlarm
    */
   public void setIntervalTimerAlarm(String a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setIntervalTimerAlarm(Long.parseLong(a0), a1.array);
   }

   /**
    * Sets the power Cycle Count Alarm. This counter holds the number
    * of times the DS1994 must experience power cycles
    * before it generates an alarm.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param cycles power Cycle Count alarm
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #getCycleCounterAlarm(byte[]) getCycleCounterAlarm
    */
   public void setCycleCounterAlarm(String a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setCycleCounterAlarm(Long.parseLong(a0), a1.array);
   }

   /**
    * Sets the write protect options for the Real-Time
    * clock/Alarm.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * <P>WARNING: after calling this method and then
    * <CODE> writeDevice </CODE> the device will be permanently write
    * protected. </P> <BR>
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #isClockWriteProtected(byte[]) isClockWriteProtected
    */
   public void writeProtectClock(ByteArray a0)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).writeProtectClock(a0.array);
   }

   /**
    * Sets the write protect options for Interval Timer and
    * Interval Timer Alarm register.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * <P>WARNING: after calling this method and then
    * <CODE> writeDevice </CODE> the device will be permanently write
    * protected. </P> <BR>
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #isIntervalTimerWriteProtected(byte[]) isIntervalTimerWriteProtected
    */
   public void writeProtectIntervalTimer(ByteArray a0)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).writeProtectIntervalTimer(a0.array);
   }

   /**
    * Sets the write protect options for the Cycle Counter
    * and Alarm register.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * <P>WARNING: after calling this method and then
    * <CODE> writeDevice </CODE> the device will be permanently write
    * protected. </P> <BR>
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #isCycleCounterWriteProtected(byte[]) isCycleCounterWriteProtected
    */
   public void writeProtectCycleCounter(ByteArray a0)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).writeProtectCycleCounter(a0.array);
   }

   /**
    * Sets the read state of the device after a
    * write protected alarm has occured.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param  readAfter <CODE>true</CODE> to read device after it
    *                 expires from a write protected alarm event
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #canReadAfterExpire(byte[]) canReadAfterExpire
    */
   public void setReadAfterExpire(boolean a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setReadAfterExpire(a0, a1.array);
   }

   /**
    * Sets the Interval timer to automatic or manual mode.
    * When in automatic mode, the interval counter will increment
    * while the devices I/O line is high after the delay select
    * period has elapsed (either 3.5 or 123 ms, see the
    * <CODE>isAutomaticDelayLong()</CODE> method).
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param  autoTimer <CODE>true</CODE> for the interval timer to operate in
    *                 automatic mode
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #isIntervalTimerAutomatic(byte[]) isIntervalTimerAutomatic
    */
   public void setIntervalTimerAutomatic(boolean a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setIntervalTimerAutomatic(a0, a1.array);
   }

   /**
    * Sets the Interval timer run/stop mode.  This only
    * has meaning if the interval timer is in manual mode
    * (not <CODE>isIntervalTimerAutomatic()</CODE>).
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param runState <CODE>true</CODE> to set the interval timer to run
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #isIntervalTimerAutomatic(byte[]) isIntervalTimerAutomatic
    * @see #isIntervalTimerStopped(byte[]) isIntervalTimerStopped
    */
   public void setIntervalTimerRunState(boolean a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setIntervalTimerRunState(a0, a1.array);
   }

   /**
    * Sets the automatic delay for the Inteval Timer and the Cycle
    * counter to either 123ms (long) or 3.5ms (regular).
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param delayLong <CODE>true</CODE> to set the interval timer to
    *                 cycle counter to increment after 123ms or <CODE>false</CODE>
    *                 for 3.5ms
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #isAutomaticDelayLong(byte[]) isAutomaticDelayLong
    */
   public void setAutomaticDelayLong(boolean a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setAutomaticDelayLong(a0, a1.array);
   }

   /**
    * Sets the Interval Timer Alarm enable.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param alarmEnable <CODE>true</CODE> to enable the interval timer alarm
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #isIntervalTimerAlarmEnabled(byte[]) isIntervalTimerAlarmEnabled
    */
   public void setIntervalTimerAlarmEnable(boolean a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setIntervalTimerAlarmEnable(a0, a1.array);
   }

   /**
    * Sets the Cycle counter Alarm enable.
    * The method <code>writeDevice(byte[])</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice(byte[])</code>.
    *
    * @param  alarmEnable <CODE>true</CODE> to enable the cycle counter alarm
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #isCycleCounterAlarmEnabled(byte[]) isCycleCounterAlarmEnabled
    */
   public void setCycleCounterAlarmEnable(boolean a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer04)objectInstance).setCycleCounterAlarmEnable(a0, a1.array);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer04)o;
      return this;
   }
}
