// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire&#174 container for a Single Addressable Switch, DS2405.  This container
 * encapsulates the functionality of the 1-Wire family type <B>05</B> (hex)</P>
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> Open drain PIO pin controlled through 1-Wire communication
 *   <LI> Logic level sensing of the PIO pin can be sensed
 *   <LI> Operating temperature range from -40&#176C to
 *        +85&#176C
 *   <li> One channel with level sensing abilities
 *   <li> Does not support activity sensing or 'Smart On' capabilities
 * </UL>
 *
 * <H3> Memory </H3>
 *
 * <P> The DS2405 has no memory beyond its 64-bit registration number. </P>
 *
 *
 * <H3> Usage </H3>
 *
 * <p>The DS2405 supports level sensing, but not activity sensing.  The code below
 * reads the state of the DS2405, extracting the latch state and the sensed level
 * of the PIO pin, then in the loop it toggles the latch state.</p>
 *
 * <code><pre>
 *      // "ID" is a byte array of size 8 with an address of a part we
 *      // have already found with family code 05 hex
 *      // "access" is a DSPortAdapter
 *
 *      int i=0;
 *      OneWireContainer05 ds2405 = (OneWireContainer05) access.getDeviceContainer(ID);
 *      ds2405.setupContainer(access,ID);
 *
 *      byte[] state = ds2405.readDevice();
 *
 *      // I know that the 2405 only has one channel (one switch)
 *      // and it doesn't support 'Smart On'
 *
 *      boolean latch_state = ds2405.getLatchState(0,state);
 *      System.out.println("Current state of switch: "+latch_state);
 *      System.out.println("Current output level:    "+ds2405.getLevel(0,state));
 *      while (++i &lt; 100)
 *      {
 *          System.out.println("Toggling switch");
 *          ds2405.setLatchState(0,!latch_state,false,state);
 *          ds2405.writeDevice(state);
 *          state = ds2405.readDevice();
 *          latch_state = ds2405.getLatchState(0,state);
 *          System.out.println("Current state of switch: "+latch_state);
 *          System.out.println("Current output level:    "+ds2405.getLevel(0,state));
 *          Thread.sleep(500);
 *      }
 *
 * </pre></code>
 *
 * <p>Also see the usage example in the {@link SwitchContainer SwithContainer}
 * interface.</p>
 *
 * <H3> DataSheet </H3>
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2405.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2405.pdf</A>
 * </DL>
 *
 * Also see the {@link 
 *
 * @see OneWireSensor
 * @see SwitchContainer
 * @see OneWireContainer12
 *
 *  @version CLSID=269CE1C0-DC72-48DE-9768-7D7E6EC87849 -     0.00, 28 Aug 2000
 *  @author     KLA,DSS
 * @com.register ( clsid=269CE1C0-DC72-48DE-9768-7D7E6EC87849, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer05
   extends OneWireContainer
   implements com.ms.com.IUnknown, SwitchContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer05 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer05()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer05());
   }

   OneWireContainer05(com.dalsemi.onewire.container.OneWireContainer05 o)
   {
      super(o);
   }
   OneWireContainer05(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer05)o);
   }

   /**
    * Gets the number of channels supported by this switch.
    * Channel specific methods will use a channel number specified
    * by an integer from [0 to (<code>getNumberChannels(byte[])</code> - 1)].  Note that
    * all devices of the same family will not necessarily have the
    * same number of channels.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the number of channels for this device
    *
    * @see OneWireSensor#readDevice()
    */
   public int getNumberChannels(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).getNumberChannels(a0.array);
   }

   /**
    * Checks if the channels of this switch are 'high side'
    * switches.  This indicates that when 'on' or <code>true</code>, the switch output is
    * connect to the 1-Wire data.  If this method returns  <code>false</code>
    * then when the switch is 'on' or <code>true</code>, the switch is connected
    * to ground.
    *
    * @return <code>true</code> if the switch is a 'high side' switch,
    *         <code>false</code> if the switch is a 'low side' switch
    *
    * @see #getLatchState(int,byte[])
    */
   public boolean isHighSideSwitch()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).isHighSideSwitch();
   }

   /**
    * Checks if the channels of this switch support
    * activity sensing.  If this method returns <code>true</code> then the
    * method <code>getSensedActivity(int,byte[])</code> can be used.
    *
    * @return <code>true</code> if channels support activity sensing
    *
    * @see #getSensedActivity(int,byte[])
    * @see #clearActivity()
    */
   public boolean hasActivitySensing()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).hasActivitySensing();
   }

   /**
    * Checks if the channels of this switch support
    * level sensing.  If this method returns <code>true</code> then the
    * method <code>getLevel(int,byte[])</code> can be used.
    *
    * @return <code>true</code> if channels support level sensing
    *
    * @see #getLevel(int,byte[])
    */
   public boolean hasLevelSensing()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).hasLevelSensing();
   }

   /**
    * Checks if the channels of this switch support
    * 'smart on'. Smart on is the ability to turn on a channel
    * such that only 1-Wire device on this channel are awake
    * and ready to do an operation.  This greatly reduces
    * the time to discover the device down a branch.
    * If this method returns <code>true</code> then the
    * method <code>setLatchState(int,boolean,boolean,byte[])</code>
    * can be used with the <code>doSmart</code> parameter <code>true</code>.
    *
    * @return <code>true</code> if channels support 'smart on'
    *
    * @see #setLatchState(int,boolean,boolean,byte[])
    */
   public boolean hasSmartOn()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).hasSmartOn();
   }

   /**
    * Checks if the channels of this switch require that only one
    * channel is on at any one time.  If this method returns <code>true</code> then the
    * method <code>setLatchState(int,boolean,boolean,byte[])</code>
    * will not only affect the state of the given
    * channel but may affect the state of the other channels as well
    * to insure that only one channel is on at a time.
    *
    * @return <code>true</code> if only one channel can be on at a time.
    *
    * @see #setLatchState(int,boolean,boolean,byte[])
    */
   public boolean onlySingleChannelOn()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).onlySingleChannelOn();
   }

   /**
    * Checks the sensed level on the indicated channel.
    * To avoid an exception, verify that this switch
    * has level sensing with the  <code>hasLevelSensing()</code>.
    * Level sensing means that the device can sense the logic
    * level on its PIO pin.
    *
    * @param channel channel to execute this operation, in the range [0 to (<code>getNumberChannels(byte[])</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if level sensed is 'high' and <code>false</code> if level sensed is 'low'
    *
    * @see OneWireSensor#readDevice()
    * @see #hasLevelSensing()
    */
   public boolean getLevel(int a0, ByteArray a1)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).getLevel(a0, a1.array);
   }

   /**
    * Checks the latch state of the indicated channel.
    *
    * @param channel channel to execute this operation, in the range [0 to (<code>getNumberChannels(byte[])</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if channel latch is 'on'
    * or conducting and <code>false</code> if channel latch is 'off' and not
    * conducting.  Note that the actual output when the latch is 'on'
    * is returned from the <code>isHighSideSwitch()</code> method.
    *
    * @see OneWireSensor#readDevice()
    * @see #isHighSideSwitch()
    * @see #setLatchState(int,boolean,boolean,byte[])
    */
   public boolean getLatchState(int a0, ByteArray a1)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).getLatchState(a0, a1.array);
   }

   /**
    * Checks if the indicated channel has experienced activity.
    * This occurs when the level on the PIO pins changes.  To clear
    * the activity that is reported, call <code>clearActivity()</code>.
    * To avoid an exception, verify that this device supports activity
    * sensing by calling the method <code>hasActivitySensing()</code>.
    *
    * @param channel channel to execute this operation, in the range [0 to (<code>getNumberChannels(byte[])</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if activity was detected and <code>false</code> if no activity was detected
    *
    * @throws OneWireException if this device does not have activity sensing
    *
    * @see #hasActivitySensing()
    * @see #clearActivity()
    */
   public boolean getSensedActivity(int channel, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).getSensedActivity(channel, state.array);
   }

   /**
    * Clears the activity latches the next time possible.  For
    * example, on a DS2406/07, this happens the next time the
    * status is read with <code>readDevice()</code>.
    *
    * @throws OneWireException if this device does not support activity sensing
    *
    * @see OneWireSensor#readDevice()
    * @see #getSensedActivity(int,byte[])
    */
   public void clearActivity()
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).clearActivity();
   }

   /**
    * Sets the latch state of the indicated channel.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.
    *
    * @param channel channel to execute this operation, in the range [0 to (<code>getNumberChannels(byte[])</code> - 1)]
    * @param latchState <code>true</code> to set the channel latch 'on'
    *     (conducting) and <code>false</code> to set the channel latch 'off' (not
    *     conducting).  Note that the actual output when the latch is 'on'
    *     is returned from the <code>isHighSideSwitch()</code> method.
    * @param doSmart If latchState is 'on'/<code>true</code> then doSmart indicates
    *                  if a 'smart on' is to be done.  To avoid an exception
    *                  check the capabilities of this device using the
    *                  <code>hasSmartOn()</code> method.
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see #hasSmartOn()
    * @see #getLatchState(int,byte[])
    * @see OneWireSensor#writeDevice(byte[])
    */
   public void setLatchState(int a0, boolean a1, boolean a2, ByteArray a3)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).setLatchState(a0, a1, a2, a3.array);
   }

   /**
    * Retrieves the 1-Wire device sensor state.  This state is
    * returned as a byte array.  Pass this byte array to the 'get'
    * and 'set' methods.  If the device state needs to be changed then call
    * the 'writeDevice' to finalize the changes.
    *
    * @return 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).readDevice());
   }

   /**
    * Writes the 1-Wire device sensor state that
    * have been changed by 'set' methods.  Only the state registers that
    * changed are updated.  This is done by referencing a field information
    * appended to the state data.
    *
    * @param  state 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer05)objectInstance).writeDevice(state.array);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer05)o;
      return this;
   }
}
