// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire&#174 container for a SHA Transaction iButton, DS1963S.
 * This container encapsulates the functionality of the 1-Wire family type <B>18</B> (hex).
 * </P>
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> 4096 bits of read/write nonvolatile memory organized into 16 pages
 *   <li> 8 memory pages have 64-bit secrets and 32-bit read-only, non-rolling over write cycle counters
 *   <LI> Secrets are write only and have their own write cycle counters
 *   <li> On-chip 512-bit SHA-1 engine to compute 160-bit Message Authentication Codes
 *   <li> 256-bit scratchpad ensures integrity of data transfer
 *   <li> On-chip 16-bit CRC generator for safeguarding data transfers
 *   <li> Overdrive mode supports communication up to 142 kbits per second
 * </UL>
 *
 * <p>This container provides the functionality to use the raw power of the
 * DS1963S.  It does not immediately implement transactions and authentication.
 * The class {@link 
 * The <code>SHAiButton</code> class exists on top of this class, making higher
 * level calls to implement transactions.</p>

 * <p>This container makes use of several optimizations to help it run fast
 * on TINI.  These optimizations do little for the PC, but they do not
 * slow down the PC.  Most methods are <code>synchronized</code> because they access
 * an instance byte array.  This is less expensive than creating new byte
 * arrays for every method, because there should
 * not be contention for the resources in this container between threads.
 * Threads should use the <code>DSPortAdapter</code> methods
 * <code>beginExclusive(boolean)</code> and <code>endExclusive()</code> to synchronize on the 1-Wire port.</p>
 *
 * <p>Notice that for maximum performance, programs should call the method <code>setSpeedCheck(boolean)</code>
 * with an argument <code>false</code> before any other methods that access the
 * 1-Wire.  A program that calls this function is assumed to understand and
 * control the speed of communication on the 1-Wire bus.  If the speed check is not disabled,
 * a call to the method <code>OneWireContainer.doSpeed()</code> will occur in almost every
 * function.  While this should guarantee that the 1-Wire bus is never at an unknown speed,
 * it will slow down throughput considerably.</p>
 *
 * <H3> Memory </H3>
 *
 * <p>In the interest of speed, this container has several methods to quickly access
 * the memory of a DS9163S.  These methods include:
 * <ul>
 *     <li> {@link #eraseScratchPad(int)                    <code>eraseScratchPad</code>}
 *     <li> {@link #readScratchPad(byte[],int)              <code>readScratchPad</code>}
 *     <li> {@link #writeScratchPad(int,int,byte[],int,int) <code>writeScratchPad</code>}
 *     <li> {@link #readMemoryPage(int,byte[],int)          <code>readMemoryPage</code>}
 *     <li> {@link #readAuthenticatedPage(int,byte[],int)   <code>readAuthenticatedPage</code>}
 *     <li> {@link #writeDataPage(int,byte[])               <code>writeDataPage</code>}
 * </ul></p>
 *
 * <P> The memory can also be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 *
 * The following is a list of the MemoryBank instances that are returned:
 *
 * <UL>
 *   <LI> <B> Scratchpad with CRC and auto-hide</B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write not-general-purpose volatile
 *         <LI> <I> Pages</I> 1 page of length 32 bytes
 *         <LI> <I> Page Features </I> page-device-CRC
 *         <li> <i> Extra information for each page</i>  Target address, offset, length 3
 *      </UL>
 *   <LI> <B> Main Memory </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 256 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 8 pages of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC
 *      </UL>
 *   <LI> <B> Memory with write cycle counter </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 256 starting at physical address 256
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 8 pages of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC
 *         <li> <i> Extra information for each page</i>  Write cycle counter, length 3
 *      </UL>
 *   <LI> <B> Write cycle counters and PRNG counter </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 96 starting at physical address 608
 *         <LI> <I> Features</I> Read-only not-general-purpose non-volatile
 *         <LI> <I> Pages</I> 3 pages of length 32 bytes
 *      </UL>
 * </UL>
 *
 * <H3> Usage </H3>
 *
 * <p>For examples on using the SHA iButton for transactions and authentications, see
 * the examples in the {@link SHAiButtonUser18 SHAiButton}
 * usage section.</p>
 *
 * For examples regarding memory operations,
 * <uL>
 * <li> See the usage example in
 * {@link OneWireContainer OneWireContainer}
 * to enumerate the MemoryBanks.
 * <li> See the usage examples in
 * {@link MemoryBank MemoryBank} and
 * {@link PagedMemoryBank PagedMemoryBank}
 * for bank specific operations.
 * </uL>
 *
 * <H3> DataSheet </H3>
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS1963S.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS1963S.pdf</A>
 * </DL>
 *
 * <p>Note that the protocol for transactions using SHA iButtons calls for
 * 2 iButtons.  One belongs to the system that grants authentication and
 * is authorized to validate money.  This iButton is usually called the
 * Coprocessor.  The other iButton is the device that contains digital
 * money that must be authenticated and verified to perform transactions.
 * This iButton is usually called a User iButton, Roaming iButton,
 * or Roving iButton.</p>
 *
 * @author KLA
 * @version CLSID=211176C9-8328-4DDB-B83F-A647AE95C877 -  0.00, 28 Aug 2000
 * @see SHAiButtonUser18
 * @see DSPortAdapter#beginExclusive(boolean)
 * @see DSPortAdapter#endExclusive()
 * @see OneWireContainer#doSpeed()
 * @com.register ( clsid=211176C9-8328-4DDB-B83F-A647AE95C877, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer18
   extends OneWireContainer
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer18 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer18()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer18());
   }

   OneWireContainer18(com.dalsemi.onewire.container.OneWireContainer18 o)
   {
      super(o);
   }
   OneWireContainer18(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer18)o);
   }

   public static final byte READ_MEMORY
          = com.dalsemi.onewire.container.OneWireContainer18.READ_MEMORY;

   public static final byte WRITE_SCRATCHPAD
          = com.dalsemi.onewire.container.OneWireContainer18.WRITE_SCRATCHPAD;

   public static final byte MATCH_SCRATCHPAD
          = com.dalsemi.onewire.container.OneWireContainer18.MATCH_SCRATCHPAD;

   public static final byte ERASE_SCRATCHPAD
          = com.dalsemi.onewire.container.OneWireContainer18.ERASE_SCRATCHPAD;

   public static final byte READ_SCRATCHPAD
          = com.dalsemi.onewire.container.OneWireContainer18.READ_SCRATCHPAD;

   public static final byte READ_AUTHENTICATED_PAGE
          = com.dalsemi.onewire.container.OneWireContainer18.READ_AUTHENTICATED_PAGE;

   public static final byte COPY_SCRATCHPAD
          = com.dalsemi.onewire.container.OneWireContainer18.COPY_SCRATCHPAD;

   public static final byte COMPUTE_SHA
          = com.dalsemi.onewire.container.OneWireContainer18.COMPUTE_SHA;

   public static final byte COMPUTE_FIRST_SECRET
          = com.dalsemi.onewire.container.OneWireContainer18.COMPUTE_FIRST_SECRET;

   public static final byte COMPUTE_NEXT_SECRET
          = com.dalsemi.onewire.container.OneWireContainer18.COMPUTE_NEXT_SECRET;

   public static final byte VALIDATE_DATA_PAGE
          = com.dalsemi.onewire.container.OneWireContainer18.VALIDATE_DATA_PAGE;

   public static final byte SIGN_DATA_PAGE
          = com.dalsemi.onewire.container.OneWireContainer18.SIGN_DATA_PAGE;

   public static final byte COMPUTE_CHALLENGE
          = com.dalsemi.onewire.container.OneWireContainer18.COMPUTE_CHALLENGE;

   public static final byte AUTH_HOST
          = com.dalsemi.onewire.container.OneWireContainer18.AUTH_HOST;

   public static final byte RESUME
          = com.dalsemi.onewire.container.OneWireContainer18.RESUME;

   /**
    * Directs the container to avoid the calls to doSpeed() in methods that communicate
    * with the SHA iButton. To ensure that all parts can talk to the 1-Wire bus
    * at their desired speed, each method contains a call
    * to <code>doSpeed()</code>.  However, this is an expensive operation.
    * If a user manages the bus speed in an
    * application,  call this method with <code>doSpeedCheck</code>
    * as <code>false</code>.  The default behavior is
    * to call <code>doSpeed()</code>.
    *
    * @param doSpeedCheck <code>true</code> for <code>doSpeed()</code> to be called before every
    * 1-Wire bus access, <code>false</code> to skip this expensive call
    *
    * @see OneWireContainer#doSpeed()
    */
   public synchronized void setSpeedCheck(boolean doSpeedCheck)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).setSpeedCheck(doSpeedCheck);
   }

   /**
    * <p>Tells this <code>OneWireContainer18</code> whether it can use the <code>RESUME</code> command.
    * The <code>RESUME</code> command allows the DS1963S to be re-selected for communication
    * quickly by using a one <code>byte</code> <code>RESUME</code> command rather than a
    * nine <code>byte</code> selection sequence.  If another 1-Wire device is accessed,
    * <code>useResume(false)</code> must be called, a normal selection of the part
    * must be performed, and then <code>useResume(true)</code> can be called.</p>
    *
    * @param set <code>true</code> to use the one <code>byte</code> <code>RESUME</code> command
    * instead of the nine <code>byte</code> select command
    *
    * @see #RESUME
    */
   public synchronized void useResume(boolean set)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).useResume(set);
   }

   /**
    * <p>Erases the scratchpad of the DS1963S.  The cryptographic features
    * of the DS1963S leave the device in 'hidden mode', which makes most
    * memory functions inaccessible.  A call to <code>eraseScratchPad(int)</code>
    * brings the device out of 'hidden mode', filling the scratchpad
    * with 0x0FF <code>bytes</code>.</p>
    *
    * <p>The argument <code>page</code> is usually unimportant, except in cases
    * where a memory page needs to be erased.  Erase a memory page by calling
    * <code>eraseScratchPad(page_number)</code>, followed by <code>readScratchPad()</code>
    * and then <code>copyScratchPad()</code>.
    *
    * @param page the target page number
    *
    * @return true if successful, false if the operation failed while waiting for the
    * DS1963S's output to alternate (see the datasheet for a description)
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #waitForSuccessfulFinish()
    * @see #readScratchPad(byte[],int)
    * @see #copyScratchPad()
    */
   public synchronized boolean eraseScratchPad(int page)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).eraseScratchPad(page);
   }

   /**
    * <p>Waits for the DS1963S's output to alternate.  Several operations must
    * wait for the DS1963S to stop sending 0x0ff's and begin alternating its
    * output bits.  This method reads until it finds a non-0x0ff <code>byte</code> or until it
    * reaches a specified number of tries, indicating failure.</p>
    *
    * <p>This method can often be optimized away.  A normal 1-Wire transaction
    * involves writing and reading a known number of bytes.  If a few more bytes
    * are read, a program can check to see if the DS1963S has started alternating
    * its output much quicker than calling this method will.  For instance,
    * to copy the scratchpad, the source code might look like this:
    * <code><pre>
    *    buffer [0] = COPY_SCRATCHPAD;
    *    buffer [1] = TA1;
    *    buffer [2] = TA2;
    *    buffer [3] = ES;
    *
    *    adapter.dataBlock(buffer,0,4);
    *    return waitForSuccessfulFinish();
    * </pre></code>
    * To optimize the code, read more bytes than required:
    * <code><pre>
    *    buffer [0] = COPY_SCRATCHPAD;
    *    buffer [1] = TA1;
    *    buffer [2] = TA2;
    *    buffer [3] = ES;
    *
    *    //copy 0x0FF into the buffer, this effectively reads
    *    System.arraycopy(FF, 0, buffer, 4, 5);
    *
    *    //read 5 extra bytes
    *    adapter.dataBlock(buffer, 0, 9);
    *
    *    //if the last byte has not shown alternating output,
    *    //still call waitForSuccessfulFinish(), else
    *    //we are already done
    *    if (buffer [8] == ( byte ) 0x0ff)
    *         return waitForSuccessfulFinish();
    *     else
    *         return true;
    * </pre></code></p>
    *
    * <p>The second method is faster because it is more expensive to
    * invoke another method that goes down to the native access layer
    * than it is to just read a few more bytes while the program is
    * already at the native access layer.</p>
    *
    * <p>See the datasheet for which operations function in this manner.
    * Only call this method after another method which has successfully
    * communicated with the DS1963S.</p>
    *
    * @return <code>true</code> if the DS1963S completed its operation successfully
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #copyScratchPad()
    * @see #eraseScratchPad(int)
    * @see #readAuthenticatedPage(int,byte[],int)
    */
   public synchronized boolean waitForSuccessfulFinish()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).waitForSuccessfulFinish();
   }

   /**
    * <p>Reads a memory page from the DS1963S.  Pages 0-15 are normal memory pages.
    * Pages 16 and 17 contain the secrets--the DS1963S will return all 1's (0x0ff
    * bytes).  Page 18 is the physical location of the scratchpad, and will only
    * return valid data if the part is not in hidden mode (0x0ff bytes are returned
    * otherwise).  Pages 19 and 20 contain the write cycle counters.
    * Page 21 contains the counter for the pseudo random number generator (PRNG).
    * Consult the datasheet for the memory maps of these special pages.</p>
    *
    * <p>Note that the same data can be returned through the <code>MemoryBank</code>s
    * returned by <code>getMemoryBanks()</code>.  However, this method contains
    * several enhancements for faster reading.</p>
    *
    * @param pageNum page number to read
    * @param data array for the return of the data (must be at least 32 bytes long)
    * @param start offset into the byte array to start copying page data
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #readAuthenticatedPage(int,byte[],int)
    * @see #getMemoryBanks()
    */
   public void readMemoryPage(int pageNum, ByteArray data, int start)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).readMemoryPage(pageNum, data.array, start);
   }

   /**
    * <p>Reads and authenticates a page.  See <code>readMemoryPage()</code> for a description
    * of page numbers and their contents.  This method will also generate a signature for the
    * selected page, used in the authentication of roving (User) iButtons.
    * Extra data is returned with the page as well--such as the write cycle
    * counter for the page and the write cycle counter of the selected
    * secret page.</p>
    * <ul>
    *     <li>32 bytes of page data                </li>
    *     <li>4 bytes secret counter for page      </li>
    *     <li>4 bytes write cycle counter for page </li>
    *     <li>2 byte CRC                           </li>
    * </ul>
    * <p>Note that the CRC will be verified by this method, though it is returned with the data.</p>
    *
    * @param pageNum page number to read and authenticate
    * @param data array for the page data plus extra information (2 write cycle
    * counters of 4 bytes each, one 2 byte CRC, appended after 32 bytes of
    * the data page).  This byte array must be at least 42 bytes long.
    * @param start offset to copy into the array
    *
    * @return <code>true</code> if successful, <code>false</code> if the operation
    *         failed while waiting for the DS1963S's output to alternate
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #readMemoryPage(int,byte[],int)
    */
   public boolean readAuthenticatedPage(int pageNum, ByteArray data, int start)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).readAuthenticatedPage(pageNum, data.array, start);
   }

   /**
    * <p>Writes data to the scratchpad.  In order to write to a data page using this method,
    * next call <code>readScratchPad()</code>, and then <code>copyScratchPad()</code>.
    * Note that the addresses passed to this method will be the addresses the data is
    * copied to if the <code>copyScratchPad()</code> method is called afterward.</p>
    *
    * <p>Also note that if too many bytes are written, this method will truncate the
    * data so that only a valid number of bytes will be sent.</p>
    *
    * @param targetPage the page number this data will eventually be copied to
    * @param targetPageOffset the offset on the page to copy this data to
    * @param inputbuffer the data that will be copied into the scratchpad
    * @param start offset into the input buffer for the data to write
    * @param length number of bytes to write
    *
    * @return <code>true</code> if successful, <code>false</code> on a CRC error
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #copyScratchPad()
    * @see #eraseScratchPad(int)
    * @see #readScratchPad(byte[],int)
    * @see #writeDataPage(int,byte[])
    */
   public synchronized boolean writeScratchPad(int targetPage, int targetPageOffset, ByteArray inputbuffer, int start, int length)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).writeScratchPad(targetPage, targetPageOffset, inputbuffer.array, start, length);
   }

   /**
    * <p>Verifies the hidden signature in the scratchpad of the DS1963S.
    * After a <code>VALIDATE_DATA_PAGE</code> command, the scratchpad
    * contains a signature that cannot be read, but must be verified.
    * This method gives the DS1963S a signature.  The iButton then
    * checks to see if it equals the hidden signature in its
    * scratchpad.</p>
    *
    * <p>The signature must be 20 bytes long, and it must start at offset 0
    * of the input array.</p>
    *
    * @param mac the signature starting at offset 0
    *
    * @return <code>true</code> if the signature matches
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #VALIDATE_DATA_PAGE
    */
   public synchronized boolean matchScratchPad(ByteArray mac)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).matchScratchPad(mac.array);
   }

   /**
    * <p>Reads the contents of the DS1963S scratchpad.  If the device is in hidden
    * mode, all 1's (0x0ff bytes) will be returned.</p>
    *
    * <p>This method will return up to 32 bytes.  It may return less
    * if the target address stored internally on the DS1963S is
    * not a multiple of 32.</p>
    *
    * @param data array to hold the contents of the scratchpad
    * @param start offset to copy the scratchpad data into the <code>byte</code> array
    *
    * @return the number of bytes read, or -1 if there was a CRC failure
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #writeScratchPad(int,int,byte[],int,int)
    */
   public synchronized int readScratchPad(ByteArray data, int start)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).readScratchPad(data.array, start);
   }

   /**
    * Copies the contents of the scratchpad to the target destination
    * that was specified in a call to <code>writeScratchPad()</code> or
    * <code>eraseScratchPad()</code>.  This method will not success unless
    * a call to <code>readScratchPad()</code> is made first to verify
    * the target address registers in the DS1963S.
    *
    * @return <code>true</code> if successful, <code>false</code> if the operation
    *         failed while waiting for the DS1963S's output to alternate
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #eraseScratchPad(int)
    * @see #readScratchPad(byte[],int)
    * @see #writeScratchPad(int,int,byte[],int,int)
    */
   public synchronized boolean copyScratchPad()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).copyScratchPad();
   }

   /**
    * <p>Installs a secret on a DS1963S.  The secret is written in partial phrases
    * of 47 bytes (32 bytes to a memory page, 15 bytes to the scratchpad) and
    * is cumulative until the entire secret is processed.  Secrets are associated
    * with a page number.  See the datasheet for more information on this
    * association.</p>
    *
    * <p>In most cases, <code>page</code> should be equal to <code>secret_number</code>
    * or <code>secret_number+8</code>, based on the association of secrets and page numbers.
    * Secrets are stored across pages 16 and 17 of the DS1963S memory.  A secret is 8 bytes, so
    * there are 8 secrets.  These 8 secrets are associated with the first 16 pages of memory.</p>
    *
    * <p>On TINI, this method will be slightly faster if the secret's length is divisible by 47.
    * However, since secret key generation is a part of initialization, it is probably
    * not necessary.</p>
    *
    * @param page the page number used to write the partial secrets to
    * @param secret the entire secret, in partial phrases, to be installed
    * @param secret_number the secret 'page' to use (0 - 7)
    *
    * @return <code>true</code> if successful
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #bindSecretToiButton(int,byte[],byte[],int)
    */
   public synchronized boolean installMasterSecret(int page, ByteArray secret, int secret_number)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).installMasterSecret(page, secret.array, secret_number);
   }

   /**
    * <p>Binds an installed secret to a DS1963S by using
    * well-known binding data and the DS1963S's unique
    * address.  This makes the secret unique
    * for this iButton.  Coprocessor iButtons use this method
    * to recreate the iButton's secret to verify authentication.
    * Roving iButtons use this method to finalize their secret keys.</p>
    *
    * <p>Note that unlike in the <code>installMasterSecret()</code> method,
    * the page number does not need to be equivalent to the <code>secret_number</code>
    * modulo 8.  The new secret (installed secret + binding code) is generated
    * from this page but can be copied into another secret.  User iButtons should
    * bind to the same page the secret was installed on.  Coprocessor iButtons
    * must copy to a new secret to preserve the general system authentication
    * secret.</p>
    *
    * <p>The binding should be either 7 bytes long or 15 bytes long.
    * A 15-length <code>byte</code> array is unaltered and placed in the scratchpad
    * for the binding.  A 7-length <code>byte</code> array is combined with the page
    * number and DS1963S unique address and then placed in the scratchpad.
    * Coprocessors should use a pre-formatted 15-length <code>byte</code> array.
    * User iButtons should let the method format for them (i.e.
    * use the 7-length <code>byte</code> array option).</p>
    *
    * @param page the page number that has the master secret already installed
    * @param bind_data 32 bytes of binding data used to bind the iButton to the system
    * @param bind_code the 7-byte or 15-byte binding code
    * @param secret_number secret number to copy the resulting secret to
    *
    * @return <code>true</code> if successful
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #installMasterSecret(int,byte[],int)
    */
   public synchronized boolean bindSecretToiButton(int page, ByteArray bind_data, ByteArray bind_code, int secret_number)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).bindSecretToiButton(page, bind_data.array, bind_code.array, secret_number);
   }

   /**
    * <p>Writes a data page to the DS1963S.  This method is the equivalent of calling:
    * <ul>
    *     <li><code>eraseScratchPad(0);                                     </code></li>
    *     <li><code>writeScratchPad(page_number,0,page_data_array,0,32);    </code></li>
    *     <li><code>readScratchPad(buffer,0);                               </code></li>
    *     <li><code>copyScratchPad();                                       </code></li>
    * </ul>
    * However, this method makes several optimizations to help it
    * run faster.  Because of the optimizations, this is the preferred
    * way of writing data to a normal memory page on the DS1963S.</p>
    *
    * @param page_number page number to write
    * @param page_data page data to write (must be at least 32 bytes long)
    *
    * @return <code>true</code> if successful, <code>false</code> if the operation
    *         failed on a CRC error or while waiting for the DS1963S's output
    *         to alternate
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #eraseScratchPad(int)
    * @see #writeScratchPad(int,int,byte[],int,int)
    * @see #readScratchPad(byte[],int)
    * @see #copyScratchPad()
    */
   public synchronized boolean writeDataPage(int page_number, ByteArray page_data)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).writeDataPage(page_number, page_data.array);
   }

   /**
    * <p>Performs one of the DS1963S's cryptographic functions.  See the datasheet for
    * more information on these functions.</p>
    *
    * Valid parameters for the <code>function</code> argument are:
    * <ul>
    *    <li> COMPUTE_FIRST_SECRET  </li>
    *    <li> COMPUTE_NEXT_SECRET   </li>
    *    <li> VALIDATE_DATA_PAGE    </li>
    *    <li> SIGN_DATA_PAGE        </li>
    *    <li> COMPUTE_CHALLENGE     </li>
    *    <li> AUTH_HOST             </li>
    * </ul>
    * <p>This method uses the last target address used by this
    * <code>OneWireContainer</code>.  These are read in the
    * <code>copyScratchPad()</code> and <code>readScratchPad()</code>
    * methods.</p>
    *
    * @param function the SHA function code
    *
    * @return <code>true</code> if the function successfully completed,
    *         <code>false</code> if the operation failed on a CRC error
    *         or while waiting for the DS1963S's output to alternate
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAFunction(byte,int)
    * @see #copyScratchPad()
    * @see #readScratchPad(byte[],int)
    */
   public boolean SHAFunction(byte function)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).SHAFunction(function);
   }

   /**
    * <p>Performs one of the DS1963S's cryptographic functions.  See the datasheet for
    * more information on these functions.</p>
    *
    * Valid parameters for the <code>function</code> argument are:
    * <ul>
    *    <li> COMPUTE_FIRST_SECRET  </li>
    *    <li> COMPUTE_NEXT_SECRET   </li>
    *    <li> VALIDATE_DATA_PAGE    </li>
    *    <li> SIGN_DATA_PAGE        </li>
    *    <li> COMPUTE_CHALLENGE     </li>
    *    <li> AUTH_HOST             </li>
    * </ul>
    * <p>This method uses the last target address used by this
    * <code>OneWireContainer</code>.  These are read in the
    * <code>copyScratchPad()</code> and <code>readScratchPad()</code>
    * methods.</p>
    *
    * @param function the SHA function code
    * @param T the raw target address for the operation
    *
    * @return <code>true</code> if the function successfully completed,
    *         <code>false</code> if the operation failed on a CRC error
    *         or while waiting for the DS1963S's output to alternate
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAFunction(byte)
    * @see #copyScratchPad()
    * @see #readScratchPad(byte[],int)
    */
   public synchronized boolean SHAFunction(byte function, int T)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer18)objectInstance).SHAFunction(function, T);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer18)o;
      return this;
   }
}
