// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>1-Wire&#174 container for the '1K-Bit protected 1-Wire EEPROM with SHA-1
 *  Engine' family type <B>33</B> (hex), Dallas Semiconductor part number:
 * <B>DS1961S,DS2432</B>.
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> 1128 bits of 5V EEPROM memory partitioned into four pages of 256 bits,
 *        a 64-bit write-only secret and up to 5 general purpose read/write
 *        registers.
 *   <LI> On-chip 512-bit SHA-1 engine to compute 160-bit Message Authentication
 *        Codes (MAC) and to generate secrets.
 *   <LI> Write access requires knowledge of the secret and the capability of
 *        computing and transmitting a 160-bit MAC as authorization.
 *   <LI> Secret and data memory can be write-protected (all or page 0 only) or
 *        put in EPROM-emulation mode ("write to 0", page0)
 *   <LI> unique, fatory-lasered and tested 64-bit registration number (8-bit
 *        family code + 48-bit serial number + 8-bit CRC tester) assures
 *        absolute traceablity because no two parts are alike.
 *   <LI> Built-in multidrop controller ensures compatibility with other 1-Wire
 *        net products.
 *   <LI> Reduces control, address, data and power to a single data pin.
 *   <LI> Directly connects to a single port pin of a microprocessor and
 *        communicates at up to 16.3k bits per second.
 *   <LI> Overdrive mode boosts communication speed to 142k bits per second.
 *   <LI> 8-bit family code specifies DS2432 communication requirements to reader.
 *   <LI> Presence detector acknowledges when reader first applies voltage.
 *   <LI> Low cost 6-lead TSOC surface mount package, or solder-bumped chip scale
 *        package.
 *   <LI> Reads and writes over a wide voltage range of 2.8V to 5.25V from -40C
 *        to +85C.
 * </UL>
 *
 * <P> The memory can also be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 *
 * The following is a list of the MemoryBank instances that are returned:
 *
 * <UL>
 *   <LI> <B> Page Zero with write protection</B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Page</I> 1 page of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC and write protection.
 *      </UL>
 *   <LI> <B> Page One with EPROM mode and write protection </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32 starting at physical address 32
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Page</I> 1 page of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC, EPROM mode and write protection.
 *      </UL>
 *   <LI> <B> Page Two and Three with write protection </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 64 starting at physical address 64
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 2 pages of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC and write protection.
 *      </UL>
 *   <LI> <B> Status Page that contains the secret and the status. </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 24 starting at physical address 128
 *         <LI> <I> Page Features </I> Contains secret and status for the iButton.
 *      </UL>
 * </UL>
 *
 * <DD> <H4> Example 1</H4>
 * Display some features of isMACValid where owd is an instanceof OneWireContainer33 and
 * bank is an instanceof PagedMemoryBank:
 * <PRE> <CODE>
 *  byte[] read_buf  = new byte [bank.getPageLength()];
 *  byte[] extra_buf = new byte [bank.getExtraInfoLength()];
 *  byte[] challenge = new byte [8];
 *
 *  // read a page (use the most verbose and secure method)
 *  if (bank.hasPageAutoCRC())
 *  {
 *     System.out.println("Using device generated CRC");
 *
 *     if (bank.hasExtraInfo())
 *     {
 *        bank.readPageCRC(pg, false, read_buf, 0, extra_buf);
 *
 *        owd.getChallenge(challenge,0);
 *        owd.getContainerSecret(secret, 0);
 *        sernum = owd.getAddress();
 *        macvalid = owd.isMACValid(bank.getStartPhysicalAddress()+pg*bank.getPageLength(),
 *                                  sernum,read_buf,extra_buf,challenge,secret);
 *     }
 *     else
 *        bank.readPageCRC(pg, false, read_buf, 0);
 *  }
 *  else
 *  {
 *     if (bank.hasExtraInfo())
 *        bank.readPage(pg, false, read_buf, 0, extra_buf);
 *     else
 *        bank.readPage(pg, false, read_buf, 0);
 *  }
 * </CODE> </PRE>
 *
 * <H3> DataSheet </H3>
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2432.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2432.pdf</A>
 * </DL>
 *
 * @see SHAiButtonUser33
 * @version CLSID=CD040CDC-64D7-42A8-9776-917BD857A17F -  	0.00, 19 Dec 2000
 * @author JPE
 * @com.register ( clsid=CD040CDC-64D7-42A8-9776-917BD857A17F, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer33
   extends OneWireContainer
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer33 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer33()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer33());
   }

   OneWireContainer33(com.dalsemi.onewire.container.OneWireContainer33 o)
   {
      super(o);
   }
   OneWireContainer33(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer33)o);
   }

   /**
    * Returns the instance of the Scratchpad memory bank.  Contains
    * methods for reading/writing the Scratchpad contents.  Also,
    * methods for Load First Secret, Compute Next Secret, and
    * Refresh Scratchpad
    *
    * @return the instance of the Scratchpad memory bank
    */
   public MemoryBankScratchSHAEE getScratchpadMemoryBank()
   {      
      return new MemoryBankScratchSHAEE(((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).getScratchpadMemoryBank());
   }

   /**
    * Returns the instance of the Status page memory bank.
    *
    * @return the instance of the Status page memory bank
    */
   public MemoryBankSHAEE getStatusPageMemoryBank()
   {      
      return new MemoryBankSHAEE(((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).getStatusPageMemoryBank());
   }

   /**
    * Returns the instance of the memory bank for a particular page
    *
    * @param page the page for the requested memory bank;
    *
    * @return the instance of the memory bank for the specified page
    */
   public MemoryBankSHAEE getMemoryBankForPage(int page)
   {      
      return new MemoryBankSHAEE(((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).getMemoryBankForPage(page));
   }

   /**
    * Sets the bus master secret for this DS2432.
    *
    * @param newSecret Secret for this DS2432.
    * @param offset index into array to copy the secret from
    */
   public void setContainerSecret(ByteArray newSecret, int offset)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).setContainerSecret(newSecret.array, offset);
   }

   /**
    * Get the secret of this device as an array of bytes.
    *
    * @param secretBuf array of bytes for holding the container secret
    * @param offset index into array to copy the secret to
    */
   public void getContainerSecret(ByteArray secretBuf, int offset)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).getContainerSecret(secretBuf.array, offset);
   }

   /**
    * Get the current status of the secret.
    *
    * @return  boolean telling if the secret is set
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean isContainerSecretSet()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).isContainerSecretSet();
   }

   /**
    * Get the status of the secret, if it is write protected.
    *
    * @return  boolean telling if the secret is write protected.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean isSecretWriteProtected()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).isSecretWriteProtected();
   }

   /**
    * Sets the challenge for the Read Authenticate Page
    *
    * @param challengeset  Challenge for all the memory banks.
    */
   public void setChallenge(ByteArray  challengeset, int offset)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).setChallenge( challengeset.array, offset);
   }

   /**
    * Get the challenge of this device as an array of bytes.
    *
    * @param get  array of bytes containing the iButton challenge
    */
   public void getChallenge(ByteArray get, int offset)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).getChallenge(get.array, offset);
   }

   /**
    * Get the status of all the pages, if they are write protected.
    *
    * @return  boolean telling if all the pages are write protected.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean isWriteProtectAllSet()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).isWriteProtectAllSet();
   }

   /**
    *  Write protects the secret for the DS2432.
    */
   public void writeProtectSecret()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).writeProtectSecret();
   }

   /**
    * Write protect pages 0 to 3
    */
   public void writeProtectAll()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).writeProtectAll();
   }

   /**
    * Sets the EPROM mode for page 1.  After setting, Page One can only be written to once.
    */
   public void setEPROMModePageOne()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).setEPROMModePageOne();
   }

   /**
    * Tells if page one is in EPROM mode.
    *
    * @return  boolean telling if page one is in EPROM mode.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean isPageOneEPROMmode()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).isPageOneEPROMmode();
   }

   /**
    * Write protect page zero only.
    */
   public void writeProtectPageZero()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).writeProtectPageZero();
   }

   /**
    * Get the status of page zero, if it is write protected.
    *
    * @return  boolean telling if page zero is write protected.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean isWriteProtectPageZeroSet()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).isWriteProtectPageZeroSet();
   }

   /**
    * Compute Next Secret
    *
    * @param addr address of page to use for the next secret computation.
    * @param parialsecret the data to put into the scrathpad in computing next secret.
    */
   public void computeNextSecret(int pageNum, ByteArray partialsecret, int offset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).computeNextSecret(pageNum, partialsecret.array, offset);
   }

   /**
    * Compute Next Secret
    *
    * @param addr address of page to use for the next secret computation.
    * @param parialsecret the data to put into the scrathpad in computing next secret.
    */
   public void computeNextSecret(int pageNum)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).computeNextSecret(pageNum);
   }

   /**
    * Load First Secret
    *
    * @return              boolean saying if first secret was loaded
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean loadFirstSecret(ByteArray data, int offset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).loadFirstSecret(data.array, offset);
   }

   /**
    * Refreshes a particular 8-byte set of data on a given page.
    * This will correct any weakly-programmed EEPROM bits.  This
    * feature is only available on the DS1961S, but is safely
    * ignored on the DS2432.  The refresh consists of a Refresh Scratchpad
    * command followed by a Load First Secret to the same offset.
    *
    * @param page the page number that contains the 8-bytes to refresh.
    * @param offset the offset into the page for the 8-bytes to refresh.
    *
    * @return <code>true</code> if refresh is successful.
    */
   public boolean refreshPage(int page, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).refreshPage(page, offset);
   }

   /**
    * Refreshes a particular 8-byte set of data on a given page.
    * This will correct any weakly-programmed EEPROM bits.  This
    * feature is only available on the DS1961S, but is safely
    * ignored on the DS2432.  The refresh consists of a Refresh Scratchpad
    * command followed by a Load First Secret to the same offset.
    *
    * @param page the page number that contains the 8-bytes to refresh.
    * @param offset the offset into the page for the 8-bytes to refresh.
    *
    * @return <code>true</code> if refresh is successful.
    */
   public boolean refreshPage(int page)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).refreshPage(page);
   }

   /**
    *  Authenticates page data given a MAC.
    *
    * @param addr          address of the data to be read
    * @param memory        the memory read from the page
    * @param mac           the MAC calculated for this function given back as the extra info
    * @param challenge     the 3 bytes written to the scratch pad used in calculating the mac
    *
    */
   public boolean isMACValid(int addr, ByteArray SerNum, ByteArray memory, ByteArray mac, ByteArray challenge, ByteArray secret)
   {      
      return com.dalsemi.onewire.container.OneWireContainer33.isMACValid(addr, SerNum.array, memory.array, mac.array, challenge.array, secret.array);
   }

   /**
    * <p>Installs a secret on a DS1961S/DS2432.  The secret is written in partial phrases
    * of 47 bytes (32 bytes to a memory page, 8 bytes to the scratchpad, 7 bytes are
    * discarded (but included for compatibility with DS193S)) and
    * is cumulative until the entire secret is processed.</p>
    *
    * <p>On TINI, this method will be slightly faster if the secret's length is divisible by 47.
    * However, since secret key generation is a part of initialization, it is probably
    * not necessary.</p>
    *
    * @param page the page number used to write the partial secrets to
    * @param secret the entire secret, in partial phrases, to be installed
    *
    * @return <code>true</code> if successful
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #bindSecretToiButton(int,byte[])
    */
   public boolean installMasterSecret(int page, ByteArray newSecret)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).installMasterSecret(page, newSecret.array);
   }

   /**
    * <p>Binds an installed secret to a DS1961S/DS2432 by using
    * well-known binding data and the DS1961S/DS2432's unique
    * address.  This makes the secret unique
    * for this iButton.</p>
    *
    * @param page the page number that has the master secret already installed
    * @param bind_data 32 bytes of binding data used to bind the iButton to the system
    *
    * @return <code>true</code> if successful
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #installMasterSecret(int,byte[])
    */
   public boolean bindSecretToiButton(int pageNum, ByteArray bindData)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).bindSecretToiButton(pageNum, bindData.array);
   }

   /**
    * <p>Writes a data page to the DS1961S/DS2432.</p>
    *
    * @param page_number page number to write
    * @param page_data page data to write (must be at least 32 bytes long)
    *
    * @return <code>true</code> if successful, <code>false</code> if the operation
    *         failed
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public boolean writeDataPage(int targetPage, ByteArray pageData)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).writeDataPage(targetPage, pageData.array);
   }

   /**
    * <p>Writes a data page to the DS1961S/DS2432.</p>
    *
    * @param page_number page number to write
    * @param page_data page data to write (must be at least 32 bytes long)
    * @param offset the offset to start copying the 32-bytes of page data.
    *
    * @return <code>true</code> if successful, <code>false</code> if the operation
    *         failed
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public boolean writeDataPage(int targetPage, ByteArray pageData, int offset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).writeDataPage(targetPage, pageData.array, offset);
   }

   /**
    * <p>Writes data to the scratchpad.  In order to write to a data page using this method,
    * next call <code>readScratchPad()</code>, and then <code>copyScratchPad()</code>.
    * Note that the addresses passed to this method will be the addresses the data is
    * copied to if the <code>copyScratchPad()</code> method is called afterward.</p>
    *
    * <p>Also note that if too many bytes are written, this method will truncate the
    * data so that only a valid number of bytes will be sent.</p>
    *
    * @param targetPage the page number this data will eventually be copied to
    * @param targetPageOffset the offset on the page to copy this data to
    * @param inputbuffer the data that will be copied into the scratchpad
    * @param start offset into the input buffer for the data to write
    * @param length number of bytes to write
    *
    * @return <code>true</code> if successful, <code>false</code> on a CRC error
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public boolean writeScratchpad(int targetPage, int targetPageOffset, ByteArray inputbuffer, int start, int length)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).writeScratchpad(targetPage, targetPageOffset, inputbuffer.array, start, length);
   }

   /**
    * Read from the Scratch Pad, which is a max of 8 bytes.
    *
    * @param  scratchpad    byte array to place read data into
    *                       length of array is always pageLength.
    * @param  offset        offset into readBuf to pug data
    * @param  extraInfo     byte array to put extra info read into
    *                       (TA1, TA2, e/s byte)
    *                       Can be 'null' if extra info is not needed.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void readScratchpad(ByteArray scratchpad, int offset, ByteArray extraInfo)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).readScratchpad(scratchpad.array, offset, extraInfo.array);
   }

   /**
    * Copy all 8 bytes of the Sratch Pad to a certain page and offset in memory.
    *
    * @param targetPage the page to copy the data to
    * @param targetPageOffset the offset into the page to copy to
    * @param copy_auth byte[] containing write authorization
    * @param authStart the offset into the copy_auth array where the authorization begins.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean copyScratchpad(int targetPage, int targetPageOffset, ByteArray copy_auth, int authStart)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).copyScratchpad(targetPage, targetPageOffset, copy_auth.array, authStart);
   }

   /**
    * Copy all 8 bytes of the Sratch Pad to a certain page and offset in memory.
    *
    * @param targetPage the page to copy the data to
    * @param targetPageOffset the offset into the page to copy to
    * @param copy_auth byte[] containing write authorization
    * @param authStart the offset into the copy_auth array where the authorization begins.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean copyScratchpad(int targetPage, int targetPageOffset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).copyScratchpad(targetPage, targetPageOffset);
   }

   /**
    * Reads a page of memory..
    *
    * @param  page          page number to read packet from
    * @param  pageData       byte array to place read data into
    * @param  offset        offset into readBuf to place data
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean readMemoryPage(int page, ByteArray pageData, int offset)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).readMemoryPage(page, pageData.array, offset);
   }

   /**
    * <p>Reads and authenticates a page.  See <code>readMemoryPage()</code> for a description
    * of page numbers and their contents.  This method will also generate a signature for the
    * selected page, used in the authentication of roving (User) iButtons.</p>
    *
    * @param pageNum page number to read and authenticate
    * @param pagedata array for the page data.
    * @param offset offset to copy into the array
    * @param computed_mac array for the MAC returned by the device.
    * @param macStart offset to copy into the mac array
    *
    * @return <code>true</code> if successful, <code>false</code> if the operation
    *         failed while waiting for the DS1963S's output to alternate
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public boolean readAuthenticatedPage(int page, ByteArray pagedata, int offset, ByteArray computed_mac, int macStart)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer33)objectInstance).readAuthenticatedPage(page, pagedata.array, offset, computed_mac.array, macStart);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer33)o;
      return this;
   }
}
