// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>This class implements an account debit application for SHA Transactions.
 * Account data is stored on user iButtons after being digitally signed by
 * a coprocessor iButton. Account data consists of the following:
 *  <UL>
 *    <LI> 1 byte: Length of the account file</LI>
 *    <LI> 1 byte: Data type code (dynamic or static)</LI>
 *    <LI>20 bytes: Account Data Signature</LI>
 *    <LI> 2 bytes: Money Conversion Factor</LI>
 *    <LI> 3 bytes: Account Balance</LI>
 *    <LI> 2 bytes: Transaction ID</LI>
 *    <LI> 1 byte: File continuation pointer</LI>
 *    <LI> 2 bytes: CRC16 of entire 30 bytes seeded with the page number</LI>
 *    <LI> <B>32 bytes Total</B></LI>
 *  </UL></P>
 *
 * <P>A typical use case for this class might be as follows:
 * <pre>
 *   OneWireContainer18 coprOWC18 = new OneWireContainer18(adapter,address);
 *
 *   //COPR.0 is the filename for coprocessor service data
 *   SHAiButtonCopr copr = new SHAiButtonCopr(coprOWC18,"COPR.0");
 *
 *   //Initial amount for new users is $100, and debit amount is 50 cents
 *   SHATransaction trans = new SHADebit(copr, 10000, 50);
 *
 *   OneWireContainer18 owc18 = new OneWireContainer18(adapter, userAddress);
 *
 *   //The following constructor erases all transaction data from the user and
 *   //installs the system authentication secret on the user iButton.
 *   SHAiButtonUser user = new SHAiButtonUser18(copr, owc18, true, authSecret);
 *
 *   //creates account data on iButton
 *   if(trans.setupTransactionData(user))
 *      System.out.println("Account data installed successfully");
 *   else
 *      System.out.println("Account data installation failed");
 *
 *   //... ... ... ... ... ... ... ... ... ... ... ... ... ... ... ...
 *
 *   //"challenges" user iButton
 *   if(trans.verifyUser(user))
 *   {
 *      System.out.println("User Verified Successfully");
 *
 *      //checks data signature and account balance>0
 *      if(trans.verifyTransactionData(user))
 *      {
 *         System.out.println("Account Data Verified Successfully");
 *
 *         //debits and writes new data to user iButton
 *         if(trans.executeTransaction(user))
 *         {
 *            System.out.println("Account debited.");
 *            System.out.println("New Balance: " +
 *               trans.getParameter(SHADebit.USER_BALANCE));
 *         }
 *      }
 *   }
 *
 *   //... ... ... ... ... ... ... ... ... ... ... ... ... ... ... ...
 *
 *   if(trans.getLastError()!=0)
 *   {
 *      System.err.println("Error code: " + trans.getLastError());
 *   }
 * </pre></P>
 *
 * <p>This class makes use of several performance enhancements for TINI.
 * For instance, most methods are <code>synchronized</code> to access instance variable
 * byte arrays rather than creating new byte arrays every time a transaction
 * is performed.  This could hurt performance in multi-threaded
 * applications, but the usefulness of having several threads contending
 * to talk to a single iButton is questionable since the methods in
 * <code>DSPortAdapter</code>
 * <code>beginExclusive(boolean)</code> and <code>endExclusive()</code> should be used.</p>
 *
 * @see SHATransaction
 * @see SHAiButtonCopr
 * @see SHAiButtonUser
 *
 * @version CLSID=6082CB41-FE26-4BCB-A845-BEF4AA86347A -  1.00
 * @author  SKH
 * @com.register ( clsid=6082CB41-FE26-4BCB-A845-BEF4AA86347A, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class SHADebit
   extends SHATransaction
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: SHATransaction
   //com.dalsemi.onewire.application.sha.SHADebit objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public SHADebit()
   {
   }

   SHADebit(com.dalsemi.onewire.application.sha.SHADebit o)
   {
      super(o);
   }
   SHADebit(java.lang.Object o)
   {
      super((com.dalsemi.onewire.application.sha.SHADebit)o);
   }

   public static final int DEBIT_AMOUNT
          = com.dalsemi.onewire.application.sha.SHADebit.DEBIT_AMOUNT;

   public static final int INITIAL_AMOUNT
          = com.dalsemi.onewire.application.sha.SHADebit.INITIAL_AMOUNT;

   public static final int USER_BALANCE
          = com.dalsemi.onewire.application.sha.SHADebit.USER_BALANCE;

   public static final int I_FILE_LENGTH
          = com.dalsemi.onewire.application.sha.SHADebit.I_FILE_LENGTH;

   public static final int I_DATA_TYPE_CODE
          = com.dalsemi.onewire.application.sha.SHADebit.I_DATA_TYPE_CODE;

   public static final int I_SIGNATURE
          = com.dalsemi.onewire.application.sha.SHADebit.I_SIGNATURE;

   public static final int I_CONVERSION_FACTOR
          = com.dalsemi.onewire.application.sha.SHADebit.I_CONVERSION_FACTOR;

   public static final int I_BALANCE
          = com.dalsemi.onewire.application.sha.SHADebit.I_BALANCE;

   public static final int I_TRANSACTION_ID
          = com.dalsemi.onewire.application.sha.SHADebit.I_TRANSACTION_ID;

   public static final int I_CONTINUATION_PTR
          = com.dalsemi.onewire.application.sha.SHADebit.I_CONTINUATION_PTR;

   public static final int I_FILE_CRC16
          = com.dalsemi.onewire.application.sha.SHADebit.I_FILE_CRC16;

   /**
    * SHADebit constructor.  <code>copr</code> is the SHAiButtonCopr
    * that is used to perform this transaction.  After saving a
    * reference to the SHA coprocessor, this constructor resets all
    * parameters for this type of transaction to their default values.
    *
    * @param copr The coprocessor used for authentication and data
    *             signing in this transaction.
    */
   public void createNewInstance(SHAiButtonCopr copr)
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHADebit(((com.dalsemi.onewire.application.sha.SHAiButtonCopr)copr.objectInstance));
   }

   /**
    * SHADebit constructor.  <code>copr</code> is the SHAiButtonCopr
    * that is used to perform this transaction.  After saving a
    * reference to the SHA coprocessor, this constructor resets all
    * parameters for this type of transaction to their default values.
    *
    * @param copr The coprocessor used for authentication and data
    *             signing in this transaction.
    */
   public void createNewInstance(SHAiButtonCopr copr, int initialAmount, int debitAmount)
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHADebit(((com.dalsemi.onewire.application.sha.SHAiButtonCopr)copr.objectInstance), initialAmount, debitAmount);
   }

   /**
    * <P>Verifies user's authentication response.  User is "authenticated" if
    * and only if the digital signature generated the user iButton matches
    * the digital signature generated by the coprocessor after the user's
    * unique secret has been recreated on the coprocessor.</P>
    *
    * <P><B>Flow of action: </B>
    *   <ul>
    *     <li> Generate 3-byte "challenge" on coprocessor </li>
    *     <li> Write challenge to scratchpad of user </li>
    *     <li> Read account data page with signature </li>
    *     <li> Attempt to match user's signature with the coprocessor </li>
    *   </ul></P>
    *
    * @param user SHAiButtonUser upon which the transaction occurs.
    *
    * @see SHAiButtonCopr#generateChallenge(int,byte[],int)
    * @see SHAiButtonCopr#verifyAuthentication(byte[],byte[],byte[],byte[],byte)
    * @see SHAiButtonUser#readAccountData(byte[],int,byte[],int,byte[],int)
    * @see #getLastError()
    */
   public synchronized boolean verifyUser(SHAiButtonUser user)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHADebit)objectInstance).verifyUser(((com.dalsemi.onewire.application.sha.SHAiButtonUser)user.objectInstance));
   }

   /**
    * <P>Verifies user's account data.  Account data is "verified" if and
    * only if the account balance is greater than zero and the digital
    * signature matches the signature recreated by the coprocessor.</P>
    *
    * <P><B>Flow of action: </B>
    *   <ul>
    *     <li> Read the account data from user </li>
    *     <li> Extract account balance </li>
    *     <li> Debit money from balance </li>
    *     <li> Insert the new balance </li>
    *     <li> Reset the digital signature </li>
    *     <li> Use coprocessor to sign account data </li>
    *     <li> Insert the new digital signature </li>
    *     <li> Write the account data to the user </li>
    *   </ul></P>
    *
    * <P>If previous steps have been executed, all "Read" commands on
    * the user are reading from cached data.</P>
    *
    * @param user SHAiButtonUser upon which the transaction occurs.
    *
    * @return <code>true</code> if and only if the account balance is
    * greater than zero and digital signature matches the signature
    * recreated by the coprocessor.
    *
    * @see SHAiButtonUser#readAccountData(byte[],int)
    * @see SHAiButtonCopr#verifySignature(byte[],byte[],byte[])
    * @see #getLastError()
    */
   public synchronized boolean verifyTransactionData(SHAiButtonUser user)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHADebit)objectInstance).verifyTransactionData(((com.dalsemi.onewire.application.sha.SHAiButtonUser)user.objectInstance));
   }

   /**
    * <P>Performs the signed debit, subtracting the debit amount from
    * the user's balance and storing the new, signed account data on the
    * user's iButton.  The debit amount can be set using
    * <code>transaction.setParameter(SHADebit.DEBIT_AMOUNT, 50)</code>,
    * where the value is in units of cents (i.e. for 1 dollar, use 100).</P>
    *
    * <P><B>Flow of action: </B>
    *   <ul>
    *     <li> Read the account data from user </li>
    *     <li> Extract account balance </li>
    *     <li> Assert balance greater than debit amount </li>
    *     <li> Debit money from balance </li>
    *     <li> Insert the new balance </li>
    *     <li> Reset the digital signature </li>
    *     <li> Use coprocessor to sign account data </li>
    *     <li> Insert the new digital signature </li>
    *     <li> Write the account data to the user </li>
    *   </ul></P>
    *
    * <P>If previous steps have been executed, all "Read" commands on
    * the user are reading from cached data.</P>
    *
    * @param user SHAiButtonUser upon which the transaction occurs.
    *
    * @return <code>true</code> if and only if the user has enough in the
    * account balance to perform the requested debit AND a new digital
    * signature is successfully created AND the account data has been written
    * to the button.
    *
    * @see SHAiButtonUser#readAccountData(byte[],int)
    * @see SHAiButtonUser#writeAccountData(byte[],int)
    * @see SHAiButtonCopr#createDataSignature(byte[],byte[],byte[],int)
    * @see #getLastError()
    */
   public synchronized boolean executeTransaction(SHAiButtonUser user, boolean verifySuccess)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHADebit)objectInstance).executeTransaction(((com.dalsemi.onewire.application.sha.SHAiButtonUser)user.objectInstance), verifySuccess);
   }

   /**
    * <P>Retrieves the value of a particular parameter for this
    * debit transaction.</P>
    *
    * <P><B>Valid Parameters</B>
    *   <UL>
    *     <LI><code>SHADebit.DEBIT_AMOUNT</code></LI>
    *     <LI><code>SHADebit.INITIAL_AMOUNT</code></LI>
    *     <LI><code>SHADebit.USER_BALANCE</code></LI>
    *   </UL>
    * </P>
    *
    * <P>Note that the value of <code>SHADebit.USER_BALANCE</code> will
    * be set after calling <code>verifyTransactionData(SHAiButtonUser)</code>
    * and  after calling <code>executeTransaction(SHAiButtonUser)</code>.</P>
    *
    * @return The value of the requested parameter.
    *
    * @throws IllegalArgumentException if an invalid parameter type
    *         is requested.
    */
   public synchronized int getParameter(int type)
   {      
      return ((com.dalsemi.onewire.application.sha.SHADebit)objectInstance).getParameter(type);
   }

   /**
    * <P>Sets the value of a particular parameter for this
    * debit transaction.</P>
    *
    * <P><B>Valid Parameters</B>
    *   <UL>
    *     <LI><code>SHADebit.DEBIT_AMOUNT</code></LI>
    *     <LI><code>SHADebit.INITIAL_AMOUNT</code></LI>
    *   </UL>
    * </P>
    *
    * @param type Specifies the parameter type (<code>SHADebit.DEBIT_AMOUNT</code> or
    *        <code>SHADebit.INITIAL_AMOUNT</code>)
    * @return </code>true</code> if a valid parameter type was specified
    *         and the value of the parameter is positive.
    *
    * @throws IllegalArgumentException if an invalid parameter type
    *         is requested.
    */
   public synchronized boolean setParameter(int type, int param)
   {      
      return ((com.dalsemi.onewire.application.sha.SHADebit)objectInstance).setParameter(type, param);
   }

   /**
    * <p>Resets all transaction parameters to default values</p>
    */
   public synchronized void resetParameters()
   {      
      ((com.dalsemi.onewire.application.sha.SHADebit)objectInstance).resetParameters();
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   SHATransaction setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.application.sha.SHADebit)o;
      return this;
   }
}
