// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>Class for holding instances of SHA iButton Coprocessors involved in SHA
 * Transactions.  The Coprocessor is used for digitally signing transaction
 * data as well as generating random challenges for users and verifying
 * their response.</P>
 *
 * <p>A DS1963S SHA iButton can be a <code>SHAiButtonCopr</code> or a
 * <code>SHAiButtonUser</code>.  A Coprocessor iButton verifiessignatures
 * and signs data for User iButtons.  A Coprocessor might be located
 * inside a vending machine, where a person would bring their User iButton.  When
 * the User iButton is pressed to the Blue Dot to perform a transaction, the Coprocessor
 * would first verify that this button belongs to the system, i.e. that it knows the same
 * authentication secret (example: a Visa terminal making sure the iButton had a Visa
 * account installed). Then the Coprocessor would verify the signed data, probably money,
 * to make sure it was valid.  If someone tried to overwrite the money file, even with a
 * previously valid money file (an attempt to 'restore' a previous amount of money), the
 * signed file would be invalid because the signature includes the write cycle counter,
 * which is incremented every time a page is written to.  The write cycle counter is
 * read-only and does not roll over, so the previous amount of money could not be restored
 * by rolling the write counter. The Coprocessor verifies the money, then signs a new data
 * file that contains the new amount of money. </p>
 *
 * <p>There are two secrets involved with the transaction process.  The first secret is
 * the authentication secret.  It is used to validate a User iButton to a system.  The Coprocessor
 * iButton has the system authentication secret installed.  On User iButtons, the
 * system authentication secret is merged with binding data and the unique address
 * of the User iButton to create a unique device authentication secret.  The second secret
 * is a signing secret.  This secret only exists on the Coprocessor iButton, and is used
 * to sign and verify transaction data (i.e. money).  These secrets are inaccessible outside the
 * iButton.  Once they are installed, they cannot be retrieved.</p>
 *
 * <p>This class makes use of several performance enhancements for TINI.
 * For instance, most methods are <code>synchronized</code> to access instance variable
 * byte arrays rather than creating new byte arrays every time a transaction
 * is performed.  This could hurt performance in multi-threaded
 * applications, but the usefulness of having several threads contending
 * to talk to a single iButton is questionable since the methods in
 * <code>DSPortAdapter</code>
 * <code>beginExclusive(boolean)</code> and <code>endExclusive()</code> should be used.</p>
 *
 * @see SHATransaction
 * @see SHAiButtonUser
 *
 * @version CLSID=BA8CF6FA-7E10-4DAE-B611-AF7A96EBDA18 -  1.00
 * @author  SKH
 * @com.register ( clsid=BA8CF6FA-7E10-4DAE-B611-AF7A96EBDA18, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class SHAiButtonCopr
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.application.sha.SHAiButtonCopr objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public SHAiButtonCopr()
   {
   }

   SHAiButtonCopr(com.dalsemi.onewire.application.sha.SHAiButtonCopr o)
   {
      this.objectInstance = o;
   }
   SHAiButtonCopr(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.application.sha.SHAiButtonCopr)o);
   }

   public static final int NO_ERROR
          = com.dalsemi.onewire.application.sha.SHAiButtonCopr.NO_ERROR;

   public static final int WRITE_DATA_PAGE_FAILED
          = com.dalsemi.onewire.application.sha.SHAiButtonCopr.WRITE_DATA_PAGE_FAILED;

   public static final int WRITE_SCRATCHPAD_FAILED
          = com.dalsemi.onewire.application.sha.SHAiButtonCopr.WRITE_SCRATCHPAD_FAILED;

   public static final int MATCH_SCRATCHPAD_FAILED
          = com.dalsemi.onewire.application.sha.SHAiButtonCopr.MATCH_SCRATCHPAD_FAILED;

   public static final int ERASE_SCRATCHPAD_FAILED
          = com.dalsemi.onewire.application.sha.SHAiButtonCopr.ERASE_SCRATCHPAD_FAILED;

   public static final int COPY_SCRATCHPAD_FAILED
          = com.dalsemi.onewire.application.sha.SHAiButtonCopr.COPY_SCRATCHPAD_FAILED;

   public static final int SHA_FUNCTION_FAILED
          = com.dalsemi.onewire.application.sha.SHAiButtonCopr.SHA_FUNCTION_FAILED;

   public static final int BIND_SECRET_FAILED
          = com.dalsemi.onewire.application.sha.SHAiButtonCopr.BIND_SECRET_FAILED;

   /**
    * <P>Sets up this coprocessor object based on the provided parameters
    * and saves all of these parameters as the contents of the file
    * <code>coprFilename</code> stored on <code>owc</code>.  Then, the
    * system secret and authentication secret are installed on the
    * coprocessor button.</P>
    *
    * <P>For the proper format of the coprocessor data file, see the
    * document entitled "Implementing Secured D-Identification and E-Payment
    * Applications using SHA iButtons".  For the format of TMEX file
    * structures, see Application Note 114.</P>
    *
    * @param l_owc The DS1963S used as a coprocessor.
    * @param coprFilename The TMEX filename where coprocessor configuration
    *        data is stored.  Usually, "COPR.0".
    * @param l_formatDevice boolean indicating whether or not the TMEX
    *        filesystem of this device should be formatted before the
    *        coprocessor data file is stored.
    * @param l_signPageNumber page number used for signing user account data.
    *        (Should be page 8, but page 0 is acceptable if you don't need
    *        the TMEX directory structure)
    * @param l_authPageNumber page number used for recreating user secret.
    * @param l_wspcPageNumber page number used for storing user secret and
    *        recreating authentication MAC.
    * @param l_version version of the service provided by this coprocessor.
    * @param l_encCode refers to a type of encryption used for user account
    *        data stored on user buttons.
    * @param l_serviceFileExt the file extension used for the service file.
    *        (An extension of decimal 102 is reserved for Money files).
    * @param l_serviceFilename the 4-byte name of the user's account data
    *        file.
    * @param l_providerName the name of the provider of this service
    * @param l_bindData the binding data used to finalize secret installation
    *        on user buttons.
    * @param l_bindCode the binding code used to finalize secret installation
    *        on user buttons.
    * @param l_auxData any auxilliary or miscellaneous data to be stored on
    *        the coprocessor.
    * @param l_initialSignature the 20-byte initial MAC placed in user account
    *        data before generating actual MAC.
    * @param l_signingChlg the 3-byte challenge used for signing user
    *        account data.
    * @param l_signingSecret the system signing secret used by the
    *        service being installed on this coprocessor.
    * @param l_authSecret the system authentication secret used by the
    *        service being installed on this coprocessor.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonCopr(OneWireContainer18,String)
    */
   public void createNewInstance(OneWireContainer18 l_owc, java.lang.String coprFilename, boolean l_formatDevice, int l_signPageNumber, int l_authPageNumber, int l_wspcPageNumber, int l_version, int l_encCode, byte l_serviceFileExt, ByteArray l_serviceFilename, ByteArray coprFilename0, ByteArray coprFilename1, ByteArray coprFilename2, ByteArray coprFilename3, ByteArray coprFilename4, ByteArray coprFilename5, ByteArray coprFilename6, ByteArray coprFilename7)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonCopr(((com.dalsemi.onewire.container.OneWireContainer18)l_owc.objectInstance), coprFilename, l_formatDevice, l_signPageNumber, l_authPageNumber, l_wspcPageNumber, l_version, l_encCode, l_serviceFileExt, l_serviceFilename.array, coprFilename0.array, coprFilename1.array, coprFilename2.array, coprFilename3.array, coprFilename4.array, coprFilename5.array, coprFilename6.array, coprFilename7.array);
   }

   /**
    * <P>Sets up this coprocessor object based on the provided parameters
    * and saves all of these parameters as the contents of the file
    * <code>coprFilename</code> stored on <code>owc</code>.  Then, the
    * system secret and authentication secret are installed on the
    * coprocessor button.</P>
    *
    * <P>For the proper format of the coprocessor data file, see the
    * document entitled "Implementing Secured D-Identification and E-Payment
    * Applications using SHA iButtons".  For the format of TMEX file
    * structures, see Application Note 114.</P>
    *
    * @param l_owc The DS1963S used as a coprocessor.
    * @param coprFilename The TMEX filename where coprocessor configuration
    *        data is stored.  Usually, "COPR.0".
    * @param l_formatDevice boolean indicating whether or not the TMEX
    *        filesystem of this device should be formatted before the
    *        coprocessor data file is stored.
    * @param l_signPageNumber page number used for signing user account data.
    *        (Should be page 8, but page 0 is acceptable if you don't need
    *        the TMEX directory structure)
    * @param l_authPageNumber page number used for recreating user secret.
    * @param l_wspcPageNumber page number used for storing user secret and
    *        recreating authentication MAC.
    * @param l_version version of the service provided by this coprocessor.
    * @param l_encCode refers to a type of encryption used for user account
    *        data stored on user buttons.
    * @param l_serviceFileExt the file extension used for the service file.
    *        (An extension of decimal 102 is reserved for Money files).
    * @param l_serviceFilename the 4-byte name of the user's account data
    *        file.
    * @param l_providerName the name of the provider of this service
    * @param l_bindData the binding data used to finalize secret installation
    *        on user buttons.
    * @param l_bindCode the binding code used to finalize secret installation
    *        on user buttons.
    * @param l_auxData any auxilliary or miscellaneous data to be stored on
    *        the coprocessor.
    * @param l_initialSignature the 20-byte initial MAC placed in user account
    *        data before generating actual MAC.
    * @param l_signingChlg the 3-byte challenge used for signing user
    *        account data.
    * @param l_signingSecret the system signing secret used by the
    *        service being installed on this coprocessor.
    * @param l_authSecret the system authentication secret used by the
    *        service being installed on this coprocessor.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #SHAiButtonCopr(OneWireContainer18,String)
    */
   public void createNewInstance(OneWireContainer18 l_owc, java.lang.String coprFilename)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHAiButtonCopr(((com.dalsemi.onewire.container.OneWireContainer18)l_owc.objectInstance), coprFilename);
   }

   /**
    * <P>Returns the 8 byte address of the OneWireContainer this
    * SHAiButton refers to.</P>
    *
    * @return 8 byte array containing family code, address, and
    *         crc8 of the OneWire device.
    */
   public ByteArray getAddress()
   {      
      return new ByteArray().setupObject(objectInstance.getAddress());
   }

   /**
    * <P>Copies the 8 byte address of the OneWireContainer into
    * the provided array starting at the given offset.</P>
    *
    * @param data array with at least 8 bytes after offset
    * @param offset the index at which copying starts
    */
   public void getAddress(ByteArray data, int offset)
   {      
      objectInstance.getAddress(data.array, offset);
   }

   /**
    * <P>Copies the specified number of bytes from the address
    * of the OneWireContainer into the provided array starting
    * at the given offset.</P>
    *
    * @param data array with at least cnt bytes after offset
    * @param offset the index at which copying starts
    * @param cnt the number of bytes to copy
    */
   public void getAddress(ByteArray data, int offset, int cnt)
   {      
      objectInstance.getAddress(data.array, offset, cnt);
   }

   /**
    * <P>Returns the page number used by this coprocessor for storing
    * system authentication secret and recreating user's authentication
    * secret.  The authentication secret stays constant, while the new
    * secret is copied on to the secret corresponding to the workspace
    * page.</P>
    *
    * @return page number used for system authentication secret
    * @see OneWireContainer18#bindSecretToiButton(int,byte[],byte[],int)
    */
   public int getAuthenticationPageNumber()
   {      
      return objectInstance.getAuthenticationPageNumber();
   }

   /**
    * <P>Returns a string representing the auxilliary data associated
    * with this coprocessor's service.</P>
    *
    * @return the auxilliary data of this coprocessor's service
    */
   public java.lang.String getAuxilliaryData()
   {      
      return objectInstance.getAuxilliaryData();
   }

   /**
    * <P>Returns 7 byte binding code for finalizing secret installation
    * on user buttons.  This is copied into the user's scratchpad,
    * along with 8 other bytes of binding data (see
    * <code>bindSecretToiButton</code>) for finalizing the secret
    * and making it unique to the button.</P>
    *
    * @return the binding code for user's scratchpad
    * @see OneWireContainer18#bindSecretToiButton(int,byte[],byte[],int)
    */
   public ByteArray getBindCode()
   {      
      return new ByteArray().setupObject(objectInstance.getBindCode());
   }

   /**
    * <P>Copies 7 byte binding code for finalizing secret installation
    * on user buttons.  This is copied into the user's scratchpad,
    * along with 8 other bytes of binding data (see
    * <code>bindSecretToiButton</code>) for finalizing the secret
    * and making it unique to the button.</P>
    *
    * @param data array for copying the binding code for user's
    *        scratchpad
    * @param offset the index at which to start copying.
    * @see OneWireContainer18#bindSecretToiButton(int,byte[],byte[],int)
    */
   public void getBindCode(ByteArray data, int offset)
   {      
      objectInstance.getBindCode(data.array, offset);
   }

   /**
    * <P>Returns 32 byte binding data for finalizing secret installation
    * on user buttons.  This is copied into the user's account data
    * page (see <code>bindSecretToiButton</code>) for finalizing the
    * secret and making it unique to the button.</P>
    *
    * @return the binding data for user's data page
    * @see OneWireContainer18#bindSecretToiButton(int,byte[],byte[],int)
    */
   public ByteArray getBindData()
   {      
      return new ByteArray().setupObject(objectInstance.getBindData());
   }

   /**
    * <P>Copies 32 byte binding data for finalizing secret installation
    * on user buttons.  This is then copied into the user's account data
    * page (see <code>bindSecretToiButton</code>) for finalizing the
    * secret and making it unique to the button.</P>
    *
    * @param data array for copying the binding data for user's
    *        data page
    * @param offset the index at which to start copying.
    * @see OneWireContainer18#bindSecretToiButton(int,byte[],byte[],int)
    */
   public void getBindData(ByteArray data, int offset)
   {      
      objectInstance.getBindData(data.array, offset);
   }

   /**
    * <P>Returns an integer representing the encryption code for
    * this coprocessor.  No handling of specific encryption codes
    * are in place with this API, but could be added easily at
    * the <code>SHATransaction</codE> layer.</P>
    *
    * @return an integer representing type of encryption for user data.
    */
   public int getEncryptionCode()
   {      
      return objectInstance.getEncryptionCode();
   }

   /**
    * <P>Copies the filename (used for storing account data on user
    * buttons) into the specified array starting at the specified
    * offset.</P>
    *
    * @param l_filename the array into which the filename will be
    *        copied.
    * @param offset the starting index for copying the filename.
    */
   public void getFilename(ByteArray l_filename, int offset)
   {      
      objectInstance.getFilename(l_filename.array, offset);
   }

   /**
    * <P>Returns the extension of the filename used for storing account
    * data on user buttons.  If the type of this service is an
    * e-cash application, the file extension will be decimal 102.</P>
    *
    * @return proper file extension for user's account data file.
    */
   public byte getFilenameExt()
   {      
      return objectInstance.getFilenameExt();
   }

   /**
    * <P>Returns the 20-byte initial signature used by this coprocessor
    * for signing account data.</P>
    *
    * @return 20-byte initial signature.
    */
   public ByteArray getInitialSignature()
   {      
      return new ByteArray().setupObject(objectInstance.getInitialSignature());
   }

   /**
    * <P>Copies the 20-byte initial signature used by this coprocessor
    * for signing account data into the specified array starting at the
    * specified offset.</P>
    *
    * @param data arry for copying the 20-byte initial signature.
    * @param offset the index at which to start copying.
    */
   public void getInitialSignature(ByteArray data, int offset)
   {      
      objectInstance.getInitialSignature(data.array, offset);
   }

   /**
    * <P>Returns error code matching last error encountered by the
    * coprocessor.  An error code of zero implies NO_ERROR.</P>
    *
    * @return the error code, zero for none.
    */
   public int getLastError()
   {      
      return objectInstance.getLastError();
   }

   /**
    * <P>Returns a string representing the Provider name associated
    * with this coprocessor's service.</P>
    *
    * @return the name of the provider's service.
    */
   public java.lang.String getProviderName()
   {      
      return objectInstance.getProviderName();
   }

   /**
    * <P>Returns the 3-byte signing challenge used by this coprocessor
    * for data validation.</P>
    *
    * @return 3-byte challenge
    */
   public ByteArray getSigningChallenge()
   {      
      return new ByteArray().setupObject(objectInstance.getSigningChallenge());
   }

   /**
    * <P>Copies the 3-byte signing challenge used by this coprocessor
    * for data validation into the specified array starting at
    * the specified offset.</P>
    *
    * @param data the array for copying the 3-byte challenge.
    * @param offset the index at which to start copying.
    */
   public void getSigningChallenge(ByteArray data, int offset)
   {      
      objectInstance.getSigningChallenge(data.array, offset);
   }

   /**
    * <P>Returns the page number used by this coprocessor for signing
    * account data.</P>
    *
    * @return page number used for signing
    */
   public int getSigningPageNumber()
   {      
      return objectInstance.getSigningPageNumber();
   }

   /**
    * <P>Returns the version number of this service.</P>
    *
    * @return version number for service.
    */
   public int getVersion()
   {      
      return objectInstance.getVersion();
   }

   /**
    * <P>Returns the page number used by this coprocessor for regenerating
    * the user authentication.  This page is the target page for
    * <code>bindSecretToiButton</code> when trying to reproduce a user's
    * authentication secret.</P>
    *
    * @return page number used for regenerating user authentication.
    * @see OneWireContainer18#bindSecretToiButton(int,byte[],byte[],int)
    */
   public int getWorkspacePageNumber()
   {      
      return objectInstance.getWorkspacePageNumber();
   }

   /**
    * <P>Returns a boolean indicating whether or not this coprocessor's
    * secret's were formatted for compatibility with the DS1961S.</P>
    *
    * @return <code>true</code> if this coprocessor can authenticate a
    *         DS1961S using it's system authentication secret.
    * @see #reformatFor1961S(byte[])
    */
   public boolean isDS1961Scompatible()
   {      
      return objectInstance.isDS1961Scompatible();
   }

   /**
    * <P>Given a 32-byte array for page data and a 32-byte array for
    * scratchpad content, this function will create a 20-byte signature
    * for the data based on SHA-1.  The format of the calculation of the
    * data signature is as follows: First 4-bytes of signing secret,
    * 32-bytes of accountData, 12 bytes of scratchpad data starting at
    * index 8, last 4-bytes of signing secret, 3 bytes of scratchpad data
    * starting at index 20, and the rest is padding as specified for
    * standard SHA-1.  This is all laid out, in detail, in the DS1963S
    * data sheet.</P>
    *
    * <P>The resulting 20-byte signature is copied into
    * <code>mac_buffer</code> starting at <code>macStart</code>.  If you're
    * updating a signature that already exists in the accountData array,
    * it is acceptable to call the method like so:
    * <code><pre>
    *   copr.createDataSignature(accountData, spad, accountData, 8);
    * </pre></code>
    * assuming that the signature starts at index 8 of the accountData
    * array.</p>
    *
    * @param accountData the 32-byte data page for which the signature is
    *        generated.
    * @param signScratchpad the 32-byte scratchpad contents for which the
    *        signature is generated.  This will contain parameters such
    *        as the user's write cycle counter for the page, the user's
    *        1-wire address, and the page number where account data is
    *        stored.
    * @param mac_buffer used to return the 20-byte signature generated
    *        by signing the page using the coprocessor's system signing
    *        secret.
    * @param macStart the offset into mac_buffer where copying should start.

    * @return <code>true</code> if successful, <code>false</code> if an error
    *         occurred  (use <code>getLastError()</code> for more
    *         information on the type of error)
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see OneWireContainer18#SHAFunction(byte,int)
    * @see #getLastError()
    */
   public boolean createDataSignature(ByteArray accountData, ByteArray signScratchpad, ByteArray mac_buffer, int macStart)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.createDataSignature(accountData.array, signScratchpad.array, mac_buffer.array, macStart);
   }

   /**
    * <p>Creates a data signature, but instead of using the signing secret,
    * it uses the authentication secret, bound for a particular button.</p>
    *
    * <P>fullBindCode can be null if the secret is already bound and in
    * the signing page.</p>
    *
    * @param accountData the 32-byte data page for which the signature is
    *        generated.
    * @param signScratchpad the 32-byte scratchpad contents for which the
    *        signature is generated.  This will contain parameters such
    *        as the user's write cycle counter for the page, the user's
    *        1-wire address, and the page number where account data is
    *        stored.
    * @param mac_buffer used to return the 20-byte signature generated
    *        by signing the page using the coprocessor's system signing
    *        secret.
    * @param macStart the offset into mac_buffer where copying should start.
    * @param fullBindCode used to recreate the user iButton's unique secret

    * @return <code>true</code> if successful, <code>false</code> if an error
    *         occurred  (use <code>getLastError()</code> for more
    *         information on the type of error)
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see OneWireContainer18#SHAFunction(byte,int)
    * @see #createDataSignature(byte[],byte[],byte[],int)
    * @see #getLastError()
    */
   public boolean createDataSignatureAuth(ByteArray accountData, ByteArray signScratchpad, ByteArray mac_buffer, int macStart, ByteArray fullBindCode)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return objectInstance.createDataSignatureAuth(accountData.array, signScratchpad.array, mac_buffer.array, macStart, fullBindCode.array);
   }

   /**
    * <p>Generates a 3 byte random challenge in the iButton, sufficient to be used
    * as a challenge to be answered by a User iButton.  The user answers the challenge
    * with an authenticated read of it's account data.</p>
    *
    * <p>The DS1963S will generate 20 bytes of pseudo random data, though only
    * 3 bytes are needed for the challenge.  Programs can add more 'randomness'
    * by selecting different bytes from the 20 bytes of random data using the
    * <code>offset</code> parameter.</p>
    *
    * <p>The random number generator is actually the DS1963S's SHA engine, which requires
    * page data to compute a hash.  Select a page number with the <code>page_number</code>
    * parameter.</p>
    *
    * @param offset offset into the 20 random bytes to draw random data from
    *        (must be in range 0-16)
    * @param ch buffer for the challenge to be returned (must be of length 3 or more)
    * @param start the starting index into array <code>ch</code> to begin copying
    *        the challenge bytes.
    *
    * @return <code>true</code> if successful, <code>false</code> if an error
    *         occurred  (use <code>getLastError()</code> for more
    *         information on the type of error)
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see SHAiButtonUser#readAccountData(byte[],int,byte[],int,byte[],int)
    * @see #getLastError()
    */
   public synchronized boolean generateChallenge(int offset, ByteArray ch, int start)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.generateChallenge(offset, ch.array, start);
   }

   /**
    * <p>Determines if a <code>SHAiButtonUser</code> belongs to the system
    * defined by this Coprocessor iButton.See the usage example in this
    * class for initializing a Coprocessor iButton.</p>
    *
    * <p>The first step in user authentication is to recreate the user's
    * unique secret on the coprocessor button using
    * <code>bindSecretToiButton(int,byte[],byte[],int)</code>.  Then the
    * coprocessor signs the pageData to produce a MAC.  If the MAC matches
    * that produced by the user, the user belongs to the system.</p>
    *
    * <p>The TMEX formatted page with the user's account data is in the
    * 32-byte parameter <code>pageData</code>.  If the verification
    * is successful, the data data signature must still be verified with
    * the <code>verifySignature()</code> method.</p>
    *
    * <p>Failure of this method does not necessarily mean that
    * the User iButton does not belong to the system.  It is possible that
    * a communication disruption here could cause a CRC error that
    * would be indistinguishable from a failed authentication.  However,
    * repeated attempts should reveal whether it was truly a communication
    * problem or a User iButton that does not belong to the system.</p>
    *
    * @param fullBindCode 15-byte binding code used to recreate user iButtons
    *        unique secret in the coprocessor.
    * @param pageData 32-byte buffer containing the data page holding the user's
    *        account data.
    * @param scratchpad the 32-byte scratchpad contents for which the
    *        signature is generated.  This will contain parameters such
    *        as the user's write cycle counter for the page, the user's
    *        1-wire address, and the page number where account data is
    *        stored.
    * @param verify_mac the 20-byte buffer containing the user's authentication
    *        response to the coprocessor's challenge.
    *
    * @return <code>true</code> if the operation was successful and the user's
    *         MAC matches that generated by the coprocessor.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #generateChallenge(int,byte[],int)
    * @see #verifySignature(byte[],byte[],byte[])
    * @see OneWireContainer18#bindSecretToiButton(int,byte[],byte[],int)
    * @see OneWireContainer18#SHAFunction(byte,int)
    * @see OneWireContainer18#matchScratchPad(byte[])
    * @see #getLastError()
    */
   public boolean verifyAuthentication(ByteArray fullBindCode, ByteArray pageData, ByteArray scratchpad, ByteArray verify_mac, byte   authCmd)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.verifyAuthentication(fullBindCode.array, pageData.array, scratchpad.array, verify_mac.array,   authCmd);
   }

   /**
    * <P>Verifies a User iButton's signed data on this Coprocessor iButton.
    * The Coprocessor must recreate the signature based on the data in the
    * file and the contents of the given scratchpad, and then match that
    * with the signature passed in verify_mac.</P>
    *
    * @param pageData the full 32 byte TMEX file from the User iButton
    *        (from <code>verifyAuthentication</code>) with the
    * @param scratchpad the 32-byte scratchpad contents for which the
    *        signature is generated.  This will contain parameters such
    *        as the user's write cycle counter for the page, the user's
    *        1-wire address, and the page number where account data is
    *        stored.
    * @param verify_mac the 20-byte buffer containing the signature the user
    *        had stored with the account data file.
    *
    * @return <code>true<code> if the data file is valid, <code>false</code>
    *         if an error occurred (use <code>getLastError()</code> for more
    *         information on the type of error)
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #verifyAuthentication(byte[],byte[],byte[],byte[],byte)
    * @see #getLastError()
    */
   public boolean verifySignature(ByteArray pageData, ByteArray scratchpad, ByteArray verify_mac)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.verifySignature(pageData.array, scratchpad.array, verify_mac.array);
   }

   /**
    * Returns a string representing the 1-Wire address of this SHAiButton.
    *
    * @return a string containing the 8-byte address of this 1-Wire device.
    */
   public java.lang.String toString()
   {      
      return objectInstance.toString();
   }

   /**
    * <P>Static method that reformats the inputted authentication secret
    * so it is compatible with the DS1961S.  This means that for every
    * group of 47 bytes in the secret, bytes at indices 32-35 and indices
    * 44-46 are all set to 0xFF.  Check the format for secret generation
    * in the DS1961S data sheet to verify format of digest buffer.</P>
    *
    * <P>Note that if a coprocessor button uses this formatted secret,
    * this function should be called for all user buttons including the
    * DS1963S and DS1961S to ensure compatibility</P>
    *
    * @param auth_secret the authentication secret to be reformatted.
    *
    * @return a reformatted authentication secret, with the appropriate
    *         padding for DS1961S interaction.
    */
   public ByteArray reformatFor1961S(ByteArray auth_secret)
   {      
      return new ByteArray().setupObject(com.dalsemi.onewire.application.sha.SHAiButtonCopr.reformatFor1961S(auth_secret.array));
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   SHAiButtonCopr setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.application.sha.SHAiButtonCopr)o;
      return this;
   }
}
